/************************************************************************//**
 *
 * @file    itc_w34_w35_w36_reg.h
 *
 * @brief   Definition of the Interrupt Controller(ITC) Register
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ******************************************************************************/
#ifndef ITC_REG_H__
#define ITC_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// ITC Interrupt Level Setup Register 0
typedef union ITCLV0_REG_TAG {
    unsigned short  reg;
    struct ITCLV0_REG_BIT_TAG {
        /**
         * Supply voltage detector interrupt.
         * .ILV0[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV0[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV0        : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * Port interrupt.
         * .ILV1[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV1[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV1        : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV0_REG;

/// ITC Interrupt Level Setup Register 1
typedef union ITCLV1_REG_TAG {
    unsigned short  reg;
    struct ITCLV1_REG_BIT_TAG {
        /**
         * Power generator interrupt.
         * .ILV2[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV2[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV2        : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * Clock generator interrupt.
         * .ILV3[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV3[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV3        : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV1_REG;

/// ITC Interrupt Level Setup Register 2
typedef union ITCLV2_REG_TAG {
    unsigned short  reg;
    struct ITCLV2_REG_BIT_TAG {
        /**
         * Real-time clock interrupt.
         * .ILV4[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV4[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV4        : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * 16-bit timer Ch.0 interrupt.
         * .ILV5[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV5[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV5        : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV2_REG;

/// ITC Interrupt Level Setup Register 3
typedef union ITCLV3_REG_TAG {
    unsigned short  reg;
    struct ITCLV3_REG_BIT_TAG {
        /**
         * UART Ch.0 interrupt.
         * .ILV6[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV6[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV6        : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * 16-bit timer Ch.1 interrupt.
         * .ILV7[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV7[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV7        : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV3_REG;

/// ITC Interrupt Level Setup Register 4
typedef union ITCLV4_REG_TAG {
    unsigned short  reg;
    struct ITCLV4_REG_BIT_TAG {
        /**
         * Synchronous serial interface Ch.0 interrupt.
         * .ILV8[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV8[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV8        : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * I2C Ch.0 interrupt.
         * .ILV9[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV9[2:0] | Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV9        : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV4_REG;

/// ITC Interrupt Level Setup Register 5
typedef union ITCLV5_REG_TAG {
    unsigned short  reg;
    struct ITCLV5_REG_BIT_TAG {
        /**
         * 16-bit PWM timer Ch.0 interrupt.
         * .ILV10[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV10[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV10       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * 16-bit PWM timer Ch.1 interrupt.
         * .ILV11[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV11[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV11       : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV5_REG;

/// ITC Interrupt Level Setup Register 6
typedef union ITCLV6_REG_TAG {
    unsigned short  reg;
    struct ITCLV6_REG_BIT_TAG {
        /**
         * 16-bit PWM timer Ch.2 interrupt.
         * .ILV12[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV12[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV12       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * UART ch.1 interrupt.
         * .ILV13[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV13[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV13       : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV6_REG;

/// ITC Interrupt Level Setup Register 7
typedef union ITCLV7_REG_TAG {
    unsigned short  reg;
    struct ITCLV7_REG_BIT_TAG {
        /**
         * 16-bit timer Ch.2 interrupt.
         * .ILV14[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV14[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV14       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * Synchronous serial interface Ch.1 interrupt.
         * .ILV15[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV15[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV15       : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV7_REG;

/// ITC Interrupt Level Setup Register 8
typedef union ITCLV8_REG_TAG {
    unsigned short  reg;
    struct ITCLV8_REG_BIT_TAG {
        /**
         * Sound generator interrupt.
         * .ILV16[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV16[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV16       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * IR remote controller interrupt.
         * .ILV17[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV17[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV17       : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV8_REG;

/// ITC Interrupt Level Setup Register 9
typedef union ITCLV9_REG_TAG {
    unsigned short  reg;
    struct ITCLV9_REG_BIT_TAG {
        /**
         * LCD driver interrupt.
         * .ILV18[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV18[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV18       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * R/F converter Ch.0 interrupt.
         * .ILV19[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV19[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV19       : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV9_REG;

/// ITC Interrupt Level Setup Register 10
typedef union ITCLV10_REG_TAG {
    unsigned short  reg;
    struct ITCLV10_REG_BIT_TAG {
        /**
         * R/F converter Ch.1 interrupt.
         * .ILV20[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV20[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV20       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * 16-bit timer Ch.3 interrupt.
         * .ILV21[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV21[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV21       : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV10_REG;

/// ITC Interrupt Level Setup Register 11
typedef union ITCLV11_REG_TAG {
    unsigned short  reg;
    struct ITCLV11_REG_BIT_TAG {
        /**
         * 12-bit A/D converter Ch.0 interrupt.
         * .ILV22[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV22[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV22       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * P4-P5 Port interrupt.
         * .ILV23[2:0]
         *  These bits set the interrupt level of each interrupt.
         * +-----------+-----------------+----------+
         * | ILV23[2:0]| Interrupt level | Priority |
         * +-----------+-----------------+----------+
         * |    0x7    |        7        |   High   |
         * +-----------+-----------------+          +
         * |    0x6    |        6        |          |
         * +-----------+-----------------+          +
         * |     :     |        :        |          |
         * +-----------+-----------------+          +
         * |    0x1    |        1        |          |
         * +-----------+-----------------+          +
         * |    0x0    |        0        |   Low    |
         * +-----------+-----------------+----------+
         */
        unsigned short      ILV23       : 3;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ITCLV11_REG;

#ifdef __cplusplus
}
#endif

#endif // ITC_REG_H__
