/************************************************************************//**
 *
 * @file    c17_adc12a.h
 *
 * @brief   This is ADC12A driver header file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_ADC12A_H__
#define C17_ADC12A_H__

#include <c17_mcu_select.h>

/* --- definition --- */

enum
{
	C17_ADC12A_MODE_ONETIME,		///< One-time conversion mode
	C17_ADC12A_MODE_CONT			///< Continuous conversion mode.
};

enum
{
	C17_ADC12A_TRG_SOFT,			///< Trigger source = Software.
	C17_ADC12A_TRG_T16,				///< Trigger source = T16 CH.3 timer.
	C17_ADC12A_TRG_RESERVED,		///< reserved.
	C17_ADC12A_TRG_EXTERNAL			///< Trigger source = #ADTRGn pin.
};

enum
{
	C17_ADC12A_START0,				///< A/D converted first = Ain0.
	C17_ADC12A_START1,				///< A/D converted first = Ain1.
	C17_ADC12A_START2,				///< A/D converted first = Ain2.
	C17_ADC12A_START3,				///< A/D converted first = Ain3.
	C17_ADC12A_START4,				///< A/D converted first = Ain4.
	C17_ADC12A_START5,				///< A/D converted first = Ain5.
	C17_ADC12A_START6,				///< A/D converted first = Ain6.
	C17_ADC12A_START7				///< A/D converted first = Ain7.
};

enum
{
	C17_ADC12A_END0,				///< A/D converted last = Ain0.
	C17_ADC12A_END1,				///< A/D converted last = Ain1.
	C17_ADC12A_END2,				///< A/D converted last = Ain2.
	C17_ADC12A_END3,				///< A/D converted last = Ain3.
	C17_ADC12A_END4,				///< A/D converted last = Ain4.
	C17_ADC12A_END5,				///< A/D converted last = Ain5.
	C17_ADC12A_END6,				///< A/D converted last = Ain6.
	C17_ADC12A_END7					///< A/D converted last = Ain7.
};

/* --- external declaration --- */
extern void c17intAd12(void)		__attribute__ ((interrupt_handler));

extern void c17initAdc(void);
extern void c17setAdc12Ch0(unsigned short cnvmode, unsigned short trigger, unsigned short start, unsigned short end);
extern void c17startAdc(void);
extern void c17stopAdc(void);
extern void c17enableIntAdc(void);
extern void c17disableIntAdc(void);

#endif	// C17_ADC12A_H__

