/************************************************************************//**
 *
 * @file    c17_lcd32b.h
 *
 * @brief   This is LCD32B driver header file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_LCD32B_H__
#define C17_LCD32B_H__

#include <c17_mcu_select.h>

/* --- definition --- */
enum
{
	C17_LCD_CLKSRC_IOSC,				///< Clock Source = IOSC
	C17_LCD_CLKSRC_OSC1,				///< Clock Source = OSC1
	C17_LCD_CLKSRC_OSC3,				///< Clock Source = OSC3
	C17_LCD_CLKSRC_EXT					///< Clock Source = External OSC
};

enum
{
	C17_LCD_CLKDIV_4,					///< Clock Division = 1/4
	C17_LCD_CLKDIV_8,					///< Clock Division = 1/8
	C17_LCD_CLKDIV_16,					///< Clock Division = 1/16
	C17_LCD_CLKDIV_32,					///< Clock Division = 1/32
	C17_LCD_CLKDIV_64,					///< Clock Division = 1/64
	C17_LCD_CLKDIV_128					///< Clock Division = 1/128
};

enum
{
	C17_LCD_STATE_OFF,					///< Mode : Display off.
	C17_LCD_STATE_NORMAL,				///< Mode : Normal display.
	C17_LCD_STATE_ALL_ON,				///< Mode : All on.
	C17_LCD_STATE_ALL_OFF				///< Mode : All off.
};

enum
{
	C17_LCD_DISPLAY_AREA0,				///< Area : Display Area 0.
	C17_LCD_DISPLAY_AREA1				///< Area : Display Area 1.
};

enum
{
	C17_LCD_DISPLAY_INVERTED,			///< Inverted display
	C17_LCD_DISPLAY_NORMAL				///< Normal display
};

// Display Memory Address.
#define	LCD32B_SEGRAM_TOP_ADDR_AREA0	(0x7000) 			///< The display data RAM address(Area0).
#define	LCD32B_SEGRAM_TOP_ADDR_AREA1	(0x7200) 			///< The display data RAM address(Area1).
#define	LCD32B_SEGRAM_SIZE				(0x100)				///< The display data RAM size.

/* --- external declaration --- */
extern void c17intLcd32b(void)	__attribute__ ((interrupt_handler));

extern void c17initLcd32b(void);
extern void c17setLcd32b(unsigned short lcdClkSrc, unsigned short lcdClkDiv);
extern void c17enableIntLcd32b(void);
extern void c17disableIntLcd32b(void);
extern void c17onLcd32bDisplay(void);
extern void c17offLcd32bDisplay(void);
extern void c17setLcd32bDisplayState(unsigned char state);
extern unsigned char c17getLcd32bDisplayState(void);
extern void c17setLcd32bDisplayArea(unsigned char area);
extern unsigned char c17getLcd32bDisplayArea(void);
extern void c17setLcd32bDisplayInverted(unsigned char display);
extern unsigned char c17getLcd32bDisplayInverted(void);
extern void c17clearLcd32bDisplayData(unsigned char area);
extern void c17setLcd32bCheckerboardPatternSmall(unsigned char area);
extern void c17setLcd32bCheckerboardPatternMedium(unsigned char area);
extern void c17setLcd32bCheckerboardPatternLarge(unsigned char area);

#endif // C17_LCD32B_H__

