/************************************************************************//**
 *
 * @file    c17_rfc.c
 *
 * @brief   This is RFC Registers setting program.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2020. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Oct. 2017    1.10
 *              - Change source code.
 *          - 01 Jun. 2020    1.20
 *              - Change source code.
 *
 ***************************************************************************/
#include <stdlib.h>
#include "crt0.h"
#include "c17_misc.h"
#include "c17_rfc.h"
#include "c17_init_config.h"

#if defined(C17_PE_RFC)
/* --- interrupt handler (GNU17v3 Only) --- */
#ifdef CRT0_LINKED
#if defined(C17_MCUSEL_M01)
C17_INTERRUPT_HANDLER(_vector18_handler, c17intRfcCh0);		// RFC CH.0 interrupt
#endif
#if defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14)
C17_INTERRUPT_HANDLER(_vector20_handler, c17intRfcCh0);		// RFC CH.0 interrupt
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36)
C17_INTERRUPT_HANDLER(_vector23_handler, c17intRfcCh0);		// RFC CH.0 interrupt
C17_INTERRUPT_HANDLER(_vector24_handler, c17intRfcCh1);		// RFC CH.1 interrupt
#endif
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
C17_INTERRUPT_HANDLER(_vector20_handler, c17intRfcCh0);		// RFC CH.0 interrupt
C17_INTERRUPT_HANDLER(_vector21_handler, c17intRfcCh1);		// RFC CH.1 interrupt
#endif
#if defined(C17_MCUSEL_W15)
C17_INTERRUPT_HANDLER(_vector20_handler, c17intRfcCh0);		// RFC CH.0 interrupt
C17_INTERRUPT_HANDLER(_vector21_handler, c17intRfcCh1);		// RFC CH.1 interrupt
C17_INTERRUPT_HANDLER(_vector22_handler, c17intRfcCh2);		// RFC CH.2 interrupt
C17_INTERRUPT_HANDLER(_vector23_handler, c17intRfcCh3);		// RFC CH.3 interrupt
#endif
#endif /* CRT0_LINKED */

/* --- macro definition --- */
#if defined(C17_MCUSEL_M01) || \
	defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14)
#define CH_MAX_COUNT	1
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
#define CH_MAX_COUNT	2
#endif
#if defined(C17_MCUSEL_W15)
#define CH_MAX_COUNT	4
#endif

/* --- static const variable --- */
#if defined(C17_MCUSEL_M01) || \
	defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14)
volatile RFCNCLK_REG* const rfcnclk_table[CH_MAX_COUNT] = {(RFCNCLK_REG *)&RFC0CLK};
volatile RFCNCTL_REG* const rfcnctl_table[CH_MAX_COUNT] = {(RFCNCTL_REG *)&RFC0CTL};
volatile RFCNTRG_REG* const rfcntrg_table[CH_MAX_COUNT] = {(RFCNTRG_REG *)&RFC0TRG};
volatile RFCNMCL_REG* const rfcnmcl_table[CH_MAX_COUNT] = {(RFCNMCL_REG *)&RFC0MCL};
volatile RFCNMCH_REG* const rfcnmch_table[CH_MAX_COUNT] = {(RFCNMCH_REG *)&RFC0MCH};
volatile RFCNTCL_REG* const rfcntcl_table[CH_MAX_COUNT] = {(RFCNTCL_REG *)&RFC0TCL};
volatile RFCNTCH_REG* const rfcntch_table[CH_MAX_COUNT] = {(RFCNTCH_REG *)&RFC0TCH};
volatile RFCNINTF_REG* const rfcnintf_table[CH_MAX_COUNT] = {(RFCNINTF_REG *)&RFC0INTF};
volatile RFCNINTE_REG* const rfcninte_table[CH_MAX_COUNT] = {(RFCNINTE_REG *)&RFC0INTE};
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
volatile RFCNCLK_REG* const rfcnclk_table[CH_MAX_COUNT] = {(RFCNCLK_REG *)&RFC0CLK,(RFCNCLK_REG *)&RFC1CLK};
volatile RFCNCTL_REG* const rfcnctl_table[CH_MAX_COUNT] = {(RFCNCTL_REG *)&RFC0CTL,(RFCNCTL_REG *)&RFC1CTL};
volatile RFCNTRG_REG* const rfcntrg_table[CH_MAX_COUNT] = {(RFCNTRG_REG *)&RFC0TRG,(RFCNTRG_REG *)&RFC1TRG};
volatile RFCNMCL_REG* const rfcnmcl_table[CH_MAX_COUNT] = {(RFCNMCL_REG *)&RFC0MCL,(RFCNMCL_REG *)&RFC1MCL};
volatile RFCNMCH_REG* const rfcnmch_table[CH_MAX_COUNT] = {(RFCNMCH_REG *)&RFC0MCH,(RFCNMCH_REG *)&RFC1MCH};
volatile RFCNTCL_REG* const rfcntcl_table[CH_MAX_COUNT] = {(RFCNTCL_REG *)&RFC0TCL,(RFCNTCL_REG *)&RFC1TCL};
volatile RFCNTCH_REG* const rfcntch_table[CH_MAX_COUNT] = {(RFCNTCH_REG *)&RFC0TCH,(RFCNTCH_REG *)&RFC1TCH};
volatile RFCNINTF_REG* const rfcnintf_table[CH_MAX_COUNT] = {(RFCNINTF_REG *)&RFC0INTF,(RFCNINTF_REG *)&RFC1INTF};
volatile RFCNINTE_REG* const rfcninte_table[CH_MAX_COUNT] = {(RFCNINTE_REG *)&RFC0INTE,(RFCNINTE_REG *)&RFC1INTE};
#endif
#if defined(C17_MCUSEL_W15)
volatile RFCNCLK_REG* const rfcnclk_table[CH_MAX_COUNT] = {(RFCNCLK_REG *)&RFC0CLK,(RFCNCLK_REG *)&RFC1CLK,(RFCNCLK_REG *)&RFC2CLK,(RFCNCLK_REG *)&RFC3CLK};
volatile RFCNCTL_REG* const rfcnctl_table[CH_MAX_COUNT] = {(RFCNCTL_REG *)&RFC0CTL,(RFCNCTL_REG *)&RFC1CTL,(RFCNCTL_REG *)&RFC2CTL,(RFCNCTL_REG *)&RFC3CTL};
volatile RFCNTRG_REG* const rfcntrg_table[CH_MAX_COUNT] = {(RFCNTRG_REG *)&RFC0TRG,(RFCNTRG_REG *)&RFC1TRG,(RFCNTRG_REG *)&RFC2TRG,(RFCNTRG_REG *)&RFC3TRG};
volatile RFCNMCL_REG* const rfcnmcl_table[CH_MAX_COUNT] = {(RFCNMCL_REG *)&RFC0MCL,(RFCNMCL_REG *)&RFC1MCL,(RFCNMCL_REG *)&RFC2MCL,(RFCNMCL_REG *)&RFC3MCL};
volatile RFCNMCH_REG* const rfcnmch_table[CH_MAX_COUNT] = {(RFCNMCH_REG *)&RFC0MCH,(RFCNMCH_REG *)&RFC1MCH,(RFCNMCH_REG *)&RFC2MCH,(RFCNMCH_REG *)&RFC3MCH};
volatile RFCNTCL_REG* const rfcntcl_table[CH_MAX_COUNT] = {(RFCNTCL_REG *)&RFC0TCL,(RFCNTCL_REG *)&RFC1TCL,(RFCNTCL_REG *)&RFC2TCL,(RFCNTCL_REG *)&RFC3TCL};
volatile RFCNTCH_REG* const rfcntch_table[CH_MAX_COUNT] = {(RFCNTCH_REG *)&RFC0TCH,(RFCNTCH_REG *)&RFC1TCH,(RFCNTCH_REG *)&RFC2TCH,(RFCNTCH_REG *)&RFC3TCH};
volatile RFCNINTF_REG* const rfcnintf_table[CH_MAX_COUNT] = {(RFCNINTF_REG *)&RFC0INTF,(RFCNINTF_REG *)&RFC1INTF,(RFCNINTF_REG *)&RFC2INTF,(RFCNINTF_REG *)&RFC3INTF};
volatile RFCNINTE_REG* const rfcninte_table[CH_MAX_COUNT] = {(RFCNINTE_REG *)&RFC0INTE,(RFCNINTE_REG *)&RFC1INTE,(RFCNINTE_REG *)&RFC2INTE,(RFCNINTE_REG *)&RFC3INTE};
#endif

/* ----- static ----- */
static void setRfcPortCh0(unsigned short outclk);

#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
static void setRfcPortCh1(unsigned short outclk);
#endif

#if defined(C17_MCUSEL_W15)
static void setRfcPortCh2(unsigned short outclk);
#endif

#if defined(C17_MCUSEL_W15)
static void setRfcPortCh3(unsigned short outclk);
#endif

/************************************************************************//**
 * c17initRfc function.
 *
 * @brief   initialize RFC.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17initRfc(void)
{
	/// RFC CH 0 Setting
	if((RFCCH0_INIT & 0x0400) == 0x0400)
	{
		c17setRfc(0, (RFCCH0_INIT & 0x0300)>>8, (RFCCH0_INIT & 0x00c0)>>6, (RFCCH0_INIT & 0x001F));
		setRfcPortCh0((RFCCH0_INIT & 0x0020)>>5);

		/// Set interrupt level.
		ILVRFC_0 = INTERRUPT_LEVEL_RFC0;
	}

#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
	/// RFC CH 1 Setting
	if((RFCCH1_INIT & 0x0400) == 0x0400)
	{
		c17setRfc(1, (RFCCH1_INIT & 0x0300)>>8, (RFCCH1_INIT & 0x00c0)>>6, (RFCCH1_INIT & 0x001F));
		setRfcPortCh1((RFCCH1_INIT & 0x0020)>>5);

		/// Set interrupt level.
		ILVRFC_1 = INTERRUPT_LEVEL_RFC1;
	}
#endif

#if defined(C17_MCUSEL_W15)
	/// RFC CH 2 Setting
	if((RFCCH2_INIT & 0x0400) == 0x0400)
	{
		c17setRfc(2, (RFCCH2_INIT & 0x0300)>>8, (RFCCH2_INIT & 0x00c0)>>6, (RFCCH2_INIT & 0x001F));
		setRfcPortCh2((RFCCH2_INIT & 0x0020)>>5);

		/// Set interrupt level.
		ILVRFC_2 = INTERRUPT_LEVEL_RFC2;
	}
#endif

#if defined(C17_MCUSEL_W15)
	/// RFC CH 3 Setting
	if((RFCCH3_INIT & 0x0400) == 0x0400)
	{
		c17setRfc(3, (RFCCH3_INIT & 0x0300)>>8, (RFCCH3_INIT & 0x00c0)>>6, (RFCCH3_INIT & 0x001F));
		setRfcPortCh3((RFCCH3_INIT & 0x0020)>>5);

		/// Set interrupt level.
		ILVRFC_3 = INTERRUPT_LEVEL_RFC3;
	}
#endif
}


/************************************************************************//**
 * @brief   set RFC function.
 *
 * @param   rfcChannel              RFC CH.
 *  @li @c   0 to CH_MAX_COUNT-1
 * @param   rfcClkSrc               Clock Source.
 *  @li @c   C17_RFC_CLKSRC_IOSC
 *  @li @c   C17_RFC_CLKSRC_OSC1
 *  @li @c   C17_RFC_CLKSRC_OSC3
 *  @li @c   C17_RFC_CLKSRC_EXT
 * @param   rfcClkDiv               Clock Division
 *  @li @c   C17_RFC_CLKDIV_1 to C17_RFC_CLKDIV_8
 * @param   rfcCtl                  select operation mode
 *
 * @retval  none
 ***************************************************************************/
void c17setRfc(unsigned short rfcChannel, unsigned short rfcClkSrc, unsigned short rfcClkDiv, unsigned short rfcCtl)
{
	RFCNCLK_REG		rfcnclk_set;
	RFCNCTL_REG		rfcnctl_set;

	if(rfcChannel >= CH_MAX_COUNT) {
		return;
	}

	/// Stop RFC
	c17stopRfc(rfcChannel);

	/// Configure the RFC Ch.N operating clock.
	/* RFCNCLK: RFC Ch.N Clock Control Register. */
	{
		rfcnclk_set.reg = 0;
		rfcnclk_set.bit.DBRUN = 0;					/// - No clock supplied in DEBUG mode
		if(rfcClkSrc == C17_RFC_CLKSRC_OSC1 || rfcClkSrc == C17_RFC_CLKSRC_EXT)
		{
			/**
			 *  Clock source = OSC1/EXOSC,Clock division = C17_RFC_CLKDIV_1
			 */
			if(rfcClkDiv > C17_RFC_CLKDIV_1)
			{
				rfcClkDiv = C17_RFC_CLKDIV_1;
			}
		}
		rfcnclk_set.bit.CLKDIV = rfcClkDiv;		/// - Clock division ratio selection
		rfcnclk_set.bit.CLKSRC = rfcClkSrc;		/// - Clock source selection
		rfcnclk_table[rfcChannel]->reg =  rfcnclk_set.reg;
	}

	/// select operation mode.
	/* RFCNCTL: RFC Ch.N Control Register. */
	{
		rfcnctl_set.reg = 0;
		rfcnctl_set.reg = rfcCtl << 4;
		rfcnctl_table[rfcChannel]->reg =  rfcnctl_set.reg;
	}
}


/************************************************************************//**
 * @brief   Setting Port(GPIO) for RFC CH.0.
 *
 * @param   outclk   RFCCLKO0 enable(0)/disable(1).
 *
 * @retval  none
 ***************************************************************************/
static void setRfcPortCh0(unsigned short outclk)
{
#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
	P0MODSEL_REG	p0modsel_set;
	P0FNCSEL_REG	p0fncsel_set;
#endif
#if defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13)
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;
#endif
#if defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36)
	P2MODSEL_REG	p2modsel_set;
	P2FNCSEL_REG	p2fncsel_set;
#endif
#if defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
	P3MODSEL_REG	p3modsel_set;
	P3FNCSEL_REG	p3fncsel_set;
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23)
	P4MODSEL_REG	p4modsel_set;
	P4FNCSEL_REG	p4fncsel_set;
#endif
#if defined(C17_MCUSEL_W18)
	P6MODSEL_REG	p6modsel_set;
	P6FNCSEL_REG	p6fncsel_set;
#endif
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34)
	P7MODSEL_REG	p7modsel_set;
	P7FNCSEL_REG	p7fncsel_set;
#endif


#if defined(C17_MCUSEL_M01)
	/// Assign the RFC CH.0 input/output function to the ports.
    /*
     * P03:SENB0
     * P04:SENA0
     * P05:REF0
     * P06:REFIN0
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		/// P0 Port Mode Select Register
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P06SEL = 1;		/// - P06 : Enable peripheral I/O function.
		p0modsel_set.bit.P05SEL = 1;		/// - P05 : Enable peripheral I/O function.
		p0modsel_set.bit.P04SEL = 1;		/// - P04 : Enable peripheral I/O function.
		p0modsel_set.bit.P03SEL = 1;		/// - P03 : Enable peripheral I/O function.
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P06MUX	= 0;		/// - P06 : UPMUX.
		p0fncsel_set.bit.P05MUX	= 0;		/// - P05 : UPMUX.
		p0fncsel_set.bit.P04MUX	= 0;		/// - P04 : UPMUX.
		p0fncsel_set.bit.P03MUX	= 0;		/// - P03 : UPMUX.
		P0FNCSEL = p0fncsel_set.reg;
	}

	/// Assign the RFC CH.0 output function to the port.
	/*
	 * P00:RFCLKO0
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P0MODSEL: P0 Port Mode Select Register */
		{
			/// P0 Port Mode Select Register
			p0modsel_set.reg = P0MODSEL;
			p0modsel_set.bit.P00SEL = 1;		/// - P00 : Enable peripheral I/O function.
			P0MODSEL = p0modsel_set.reg;
		}
		/* P0FNCSEL: P0 Port Function Select Register */
		{
			p0fncsel_set.reg = P0FNCSEL;
			p0fncsel_set.bit.P00MUX	= 0;		/// - P00 : UPMUX.
			P0FNCSEL = p0fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W18)
	/// Assign the RFC CH.0 input/output function to the ports.
    /*
     * P00:SENB0
     * P01:SENA0
     * P02:REF0
     * P03:REFIN0
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		/// P0 Port Mode Select Register
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P03SEL = 1;		/// - P03 : Enable peripheral I/O function.
		p0modsel_set.bit.P02SEL = 1;		/// - P02 : Enable peripheral I/O function.
		p0modsel_set.bit.P01SEL = 1;		/// - P01 : Enable peripheral I/O function.
		p0modsel_set.bit.P00SEL = 1;		/// - P00 : Enable peripheral I/O function.
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P03MUX	= 0;		/// - P03 : UPMUX.
		p0fncsel_set.bit.P02MUX	= 0;		/// - P02 : UPMUX.
		p0fncsel_set.bit.P01MUX	= 0;		/// - P01 : UPMUX.
		p0fncsel_set.bit.P00MUX	= 0;		/// - P00 : UPMUX.
		P0FNCSEL = p0fncsel_set.reg;
	}
#if defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36)
	/// Assign the RFC CH.0 output function to the port.
	/*
	 * P25:RFCLKO0
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P2MODSEL: P2 Port Mode Select Register */
		{
			/// P2 Port Mode Select Register
			p2modsel_set.reg = P2MODSEL;
			p2modsel_set.bit.P25SEL = 1;		/// - P25 : Enable peripheral I/O function.
			P2MODSEL = p2modsel_set.reg;
		}
		/* P2FNCSEL: P2 Port Function Select Register */
		{
			p2fncsel_set.reg = P2FNCSEL;
			p2fncsel_set.bit.P25MUX	= 0;		/// - P25 : UPMUX.
			P2FNCSEL = p2fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23)
	/// Assign the RFC CH.0 output function to the port.
	/*
	 * P40:RFCLKO0
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P4MODSEL: P4 Port Mode Select Register */
		{
			/// P4 Port Mode Select Register
			p4modsel_set.reg = P4MODSEL;
			p4modsel_set.bit.P40SEL = 1;		/// - P40 : Enable peripheral I/O function.
			P4MODSEL = p4modsel_set.reg;
		}
		/* P4FNCSEL: P4 Port Function Select Register */
		{
			p4fncsel_set.reg = P4FNCSEL;
			p4fncsel_set.bit.P40MUX	= 0;		/// - P40 : UPMUX.
			P4FNCSEL = p4fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34)
	/// Assign the RFC CH.0 output function to the port.
	/*
	 * P72:RFCLKO0
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P7MODSEL: P7 Port Mode Select Register */
		{
			/// P7 Port Mode Select Register
			p7modsel_set.reg = P7MODSEL;
			p7modsel_set.bit.P72SEL = 1;		/// - P72 : Enable peripheral I/O function.
			P7MODSEL = p7modsel_set.reg;
		}
		/* P7FNCSEL: P7 Port Function Select Register */
		{
			p7fncsel_set.reg = P7FNCSEL;
			p7fncsel_set.bit.P72MUX	= 0;		/// - P72 : UPMUX.
			P7FNCSEL = p7fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16)
	/// Assign the RFC CH.0 output function to the port.
	/*
	 * P30:RFCLKO0
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P3MODSEL: P3 Port Mode Select Register */
		{
			/// P3 Port Mode Select Register
			p3modsel_set.reg = P3MODSEL;
			p3modsel_set.bit.P30SEL = 1;		/// - P30 : Enable peripheral I/O function.
			P3MODSEL = p3modsel_set.reg;
		}
		/* P3FNCSEL: P3 Port Function Select Register */
		{
			p3fncsel_set.reg = P3FNCSEL;
			p3fncsel_set.bit.P30MUX	= 0;		/// - P30 : UPMUX.
			P3FNCSEL = p3fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_W18)
	/// Assign the RFC CH.0 output function to the port.
	/*
	 * P60:RFCLKO0
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P6MODSEL: P6 Port Mode Select Register */
		{
			/// P6 Port Mode Select Register
			p6modsel_set.reg = P6MODSEL;
			p6modsel_set.bit.P60SEL = 1;		/// - P60 : Enable peripheral I/O function.
			P6MODSEL = p6modsel_set.reg;
		}
		/* P6FNCSEL: P6 Port Function Select Register */
		{
			p6fncsel_set.reg = P6FNCSEL;
			p6fncsel_set.bit.P60MUX	= 0;		/// - P60 : UPMUX.
			P6FNCSEL = p6fncsel_set.reg;
		}
	}
#endif
#endif
#if defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04)
	/// Assign the RFC CH.0 input/output function to the ports.
    /*
     * P17:SENB0
     * P16:SENA0
     * P15:REF0
     * P14:REFIN0
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		/// P1 Port Mode Select Register
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P17SEL = 1;		/// - P17 : Enable peripheral I/O function.
		p1modsel_set.bit.P16SEL = 1;		/// - P16 : Enable peripheral I/O function.
		p1modsel_set.bit.P15SEL = 1;		/// - P15 : Enable peripheral I/O function.
		p1modsel_set.bit.P14SEL = 1;		/// - P14 : Enable peripheral I/O function.
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P17MUX	= 0;		/// - P17 : UPMUX.
		p1fncsel_set.bit.P16MUX	= 0;		/// - P16 : UPMUX.
		p1fncsel_set.bit.P15MUX	= 0;		/// - P15 : UPMUX.
		p1fncsel_set.bit.P14MUX	= 0;		/// - P14 : UPMUX.
		P1FNCSEL = p1fncsel_set.reg;
	}

	/// Assign the RFC CH.0 output function to the port.
	/*
	 * P10:RFCLKO0
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P1MODSEL: P1 Port Mode Select Register */
		{
			/// P1 Port Mode Select Register
			p1modsel_set.reg = P1MODSEL;
			p1modsel_set.bit.P10SEL = 1;		/// - P10 : Enable peripheral I/O function.
			P1MODSEL = p1modsel_set.reg;
		}
		/* P1FNCSEL: P1 Port Function Select Register */
		{
			p1fncsel_set.reg = P1FNCSEL;
			p1fncsel_set.bit.P10MUX	= 0;		/// - P10 : UPMUX.
			P1FNCSEL = p1fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13)
	/// Assign the RFC CH.0 input/output function to the ports.
    /*
     * P04:SENB0
     * P05:SENA0
     * P06:REF0
     * P07:REFIN0
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		/// P0 Port Mode Select Register
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P07SEL = 1;		/// - P07 : Enable peripheral I/O function.
		p0modsel_set.bit.P06SEL = 1;		/// - P06 : Enable peripheral I/O function.
		p0modsel_set.bit.P05SEL = 1;		/// - P05 : Enable peripheral I/O function.
		p0modsel_set.bit.P04SEL = 1;		/// - P04 : Enable peripheral I/O function.
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P07MUX	= 0;		/// - P07 : UPMUX.
		p0fncsel_set.bit.P06MUX	= 0;		/// - P06 : UPMUX.
		p0fncsel_set.bit.P05MUX	= 0;		/// - P05 : UPMUX.
		p0fncsel_set.bit.P04MUX	= 0;		/// - P04 : UPMUX.
		P0FNCSEL = p0fncsel_set.reg;
	}

	/// Assign the RFC CH.0 output function to the port.
	/*
	 * P13:RFCLKO0
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P1MODSEL: P1 Port Mode Select Register */
		{
			/// P1 Port Mode Select Register
			p1modsel_set.reg = P1MODSEL;
			p1modsel_set.bit.P13SEL = 1;		/// - P13 : Enable peripheral I/O function.
			P1MODSEL = p1modsel_set.reg;
		}
		/* P1FNCSEL: P1 Port Function Select Register */
		{
			p1fncsel_set.reg = P1FNCSEL;
			p1fncsel_set.bit.P13MUX	= 0;		/// - P13 : UPMUX.
			P1FNCSEL = p1fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
	/// Assign the RFC CH.0 input/output function to the ports.
    /*
     * P33:SENB0
     * P34:SENA0
     * P35:REF0
     * P36:REFIN0
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P3MODSEL: P3 Port Mode Select Register */
	{
		/// P3 Port Mode Select Register
		p3modsel_set.reg = P3MODSEL;
		p3modsel_set.bit.P36SEL = 1;		/// - P36 : Enable peripheral I/O function.
		p3modsel_set.bit.P35SEL = 1;		/// - P35 : Enable peripheral I/O function.
		p3modsel_set.bit.P34SEL = 1;		/// - P34 : Enable peripheral I/O function.
		p3modsel_set.bit.P33SEL = 1;		/// - P33 : Enable peripheral I/O function.
		P3MODSEL = p3modsel_set.reg;
	}
	/* P3FNCSEL: P3 Port Function Select Register */
	{
		p3fncsel_set.reg = P3FNCSEL;
		p3fncsel_set.bit.P36MUX	= 0;		/// - P36 : UPMUX.
		p3fncsel_set.bit.P35MUX	= 0;		/// - P35 : UPMUX.
		p3fncsel_set.bit.P34MUX	= 0;		/// - P34 : UPMUX.
		p3fncsel_set.bit.P33MUX	= 0;		/// - P33 : UPMUX.
		P3FNCSEL = p3fncsel_set.reg;
	}

	/// Assign the RFC CH.0 output function to the port.
	/*
	 * P04:RFCLKO0
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P0MODSEL: P0 Port Mode Select Register */
		{
			/// P0 Port Mode Select Register
			p0modsel_set.reg = P0MODSEL;
			p0modsel_set.bit.P04SEL = 1;		/// - P04 : Enable peripheral I/O function.
			P0MODSEL = p0modsel_set.reg;
		}
		/* P0FNCSEL: P0 Port Function Select Register */
		{
			p0fncsel_set.reg = P0FNCSEL;
			p0fncsel_set.bit.P04MUX	= 0;		/// - P04 : UPMUX.
			P0FNCSEL = p0fncsel_set.reg;
		}
	}
#endif
}


#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
/************************************************************************//**
 * @brief   Setting Port(GPIO) for RFC CH.1.
 *
 * @param   outclk   RFCCLKO1 enable(0)/disable(1).
 *
 * @retval  none
 ***************************************************************************/
static void setRfcPortCh1(unsigned short outclk)
{
#if defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
	P0MODSEL_REG	p0modsel_set;
	P0FNCSEL_REG	p0fncsel_set;
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_W15)
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W18)
	P2MODSEL_REG	p2modsel_set;
	P2FNCSEL_REG	p2fncsel_set;
#endif
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
	P3MODSEL_REG	p3modsel_set;
	P3FNCSEL_REG	p3fncsel_set;
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
	P4MODSEL_REG	p4modsel_set;
	P4FNCSEL_REG	p4fncsel_set;
#endif
#if defined(C17_MCUSEL_W18)
	P6MODSEL_REG	p6modsel_set;
	P6FNCSEL_REG	p6fncsel_set;
#endif


#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23)
	/// Assign the RFC CH.1 input/output function to the ports.
    /*
     * P22:SENB1
     * P21:SENA1
     * P20:REF1
     * P17:REFIN1
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		/// P1 Port Mode Select Register
		p1modsel_set.reg = P0MODSEL;
		p1modsel_set.bit.P17SEL = 1;		/// - P17 : Enable peripheral I/O function.
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P0FNCSEL;
		p1fncsel_set.bit.P17MUX	= 0;		/// - P17 : UPMUX.
		P1FNCSEL = p1fncsel_set.reg;
	}

	/// Set Universal Port Multiplexer (UPMUX).
	/* P2MODSEL: P2 Port Mode Select Register */
	{
		/// P2 Port Mode Select Register
		p2modsel_set.reg = P2MODSEL;
		p2modsel_set.bit.P22SEL = 1;		/// - P22 : Enable peripheral I/O function.
		p2modsel_set.bit.P21SEL = 1;		/// - P21 : Enable peripheral I/O function.
		p2modsel_set.bit.P20SEL = 1;		/// - P20 : Enable peripheral I/O function.
		P2MODSEL = p2modsel_set.reg;
	}
	/* P2FNCSEL: P2 Port Function Select Register */
	{
		p2fncsel_set.reg = P2FNCSEL;
		p2fncsel_set.bit.P22MUX	= 0;		/// - P22 : UPMUX.
		p2fncsel_set.bit.P21MUX	= 0;		/// - P21 : UPMUX.
		p2fncsel_set.bit.P20MUX	= 0;		/// - P20 : UPMUX.
		P2FNCSEL = p2fncsel_set.reg;
	}

	/// Assign the RFC CH.1 output function to the port.
	/*
	 * P41:RFCLKO1
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P4MODSEL: P4 Port Mode Select Register */
		{
			/// P4 Port Mode Select Register
			p4modsel_set.reg = P4MODSEL;
			p4modsel_set.bit.P41SEL = 1;		/// - P41 : Enable peripheral I/O function.
			P4MODSEL = p4modsel_set.reg;
		}
		/* P4FNCSEL: P4 Port Function Select Register */
		{
			p4fncsel_set.reg = P4FNCSEL;
			p4fncsel_set.bit.P41MUX	= 0;		/// - P41 : UPMUX.
			P4FNCSEL = p4fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W18)
	/// Assign the RFC CH.1 input/output function to the ports.
    /*
     * P20:SENB1
     * P21:SENA1
     * P22:REF1
     * P23:REFIN1
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P2MODSEL: P2 Port Mode Select Register */
	{
		/// P2 Port Mode Select Register
		p2modsel_set.reg = P2MODSEL;
		p2modsel_set.bit.P23SEL = 1;		/// - P23 : Enable peripheral I/O function.
		p2modsel_set.bit.P22SEL = 1;		/// - P22 : Enable peripheral I/O function.
		p2modsel_set.bit.P21SEL = 1;		/// - P21 : Enable peripheral I/O function.
		p2modsel_set.bit.P20SEL = 1;		/// - P20 : Enable peripheral I/O function.
		P2MODSEL = p2modsel_set.reg;
	}
	/* P2FNCSEL: P2 Port Function Select Register */
	{
		p2fncsel_set.reg = P2FNCSEL;
		p2fncsel_set.bit.P23MUX	= 0;		/// - P23 : UPMUX.
		p2fncsel_set.bit.P22MUX	= 0;		/// - P22 : UPMUX.
		p2fncsel_set.bit.P21MUX	= 0;		/// - P21 : UPMUX.
		p2fncsel_set.bit.P20MUX	= 0;		/// - P20 : UPMUX.
		P2FNCSEL = p2fncsel_set.reg;
	}
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34)
	/// Assign the RFC CH.1 output function to the port.
	/*
	 * P31:RFCLKO1
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P3MODSEL: P3 Port Mode Select Register */
		{
			/// P3 Port Mode Select Register
			p3modsel_set.reg = P3MODSEL;
			p3modsel_set.bit.P31SEL = 1;		/// - P31 : Enable peripheral I/O function.
			P3MODSEL = p3modsel_set.reg;
		}
		/* P3FNCSEL: P3 Port Function Select Register */
		{
			p3fncsel_set.reg = P3FNCSEL;
			p3fncsel_set.bit.P31MUX	= 0;		/// - P31 : UPMUX.
			P3FNCSEL = p3fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_W18)
	/// Assign the RFC CH.1 output function to the port.
	/*
	 * P61:RFCLKO1
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P6MODSEL: P6 Port Mode Select Register */
		{
			/// P6 Port Mode Select Register
			p6modsel_set.reg = P6MODSEL;
			p6modsel_set.bit.P61SEL = 1;		/// - P61 : Enable peripheral I/O function.
			P6MODSEL = p6modsel_set.reg;
		}
		/* P6FNCSEL: P6 Port Function Select Register */
		{
			p6fncsel_set.reg = P6FNCSEL;
			p6fncsel_set.bit.P61MUX	= 0;		/// - P61 : UPMUX.
			P6FNCSEL = p6fncsel_set.reg;
		}
	}
#endif
#endif
#if defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36)

	/// Assign the RFC CH.1 input/output function to the ports.
    /*
     * P04:REFIN1
     * P05:REF1
     * P06:SENA1
     * P07:SENB1
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		/// P0 Port Mode Select Register
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P07SEL = 1;		/// - P03 : Enable peripheral I/O function.
		p0modsel_set.bit.P06SEL = 1;		/// - P02 : Enable peripheral I/O function.
		p0modsel_set.bit.P05SEL = 1;		/// - P01 : Enable peripheral I/O function.
		p0modsel_set.bit.P04SEL = 1;		/// - P00 : Enable peripheral I/O function.
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P07MUX	= 0;		/// - P03 : UPMUX.
		p0fncsel_set.bit.P06MUX	= 0;		/// - P02 : UPMUX.
		p0fncsel_set.bit.P05MUX	= 0;		/// - P01 : UPMUX.
		p0fncsel_set.bit.P04MUX	= 0;		/// - P00 : UPMUX.
		P0FNCSEL = p0fncsel_set.reg;
	}

	/// Assign the RFC CH.1 output function to the port.
	/*
	 * P26:RFCLKO1
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P2MODSEL: P2 Port Mode Select Register */
		{
			/// P2 Port Mode Select Register
			p2modsel_set.reg = P2MODSEL;
			p2modsel_set.bit.P26SEL = 1;		/// - P26 : Enable peripheral I/O function.
			P2MODSEL = p2modsel_set.reg;
		}
		/* P2FNCSEL: P2 Port Function Select Register */
		{
			p2fncsel_set.reg = P2FNCSEL;
			p2fncsel_set.bit.P26MUX	= 0;		/// - P26 : UPMUX.
			P2FNCSEL = p2fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W16)
	/// Assign the RFC CH.1 input/output function to the ports.
    /*
     * P40:SENB1
     * P41:SENA1
     * P42:REF1
     * P43:REFIN1
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P4MODSEL: P4 Port Mode Select Register */
	{
		/// P1 Port Mode Select Register
		p4modsel_set.reg = P4MODSEL;
		p4modsel_set.bit.P43SEL = 1;		/// - P43 : Enable peripheral I/O function.
		p4modsel_set.bit.P42SEL = 1;		/// - P42 : Enable peripheral I/O function.
		p4modsel_set.bit.P41SEL = 1;		/// - P41 : Enable peripheral I/O function.
		p4modsel_set.bit.P40SEL = 1;		/// - P40 : Enable peripheral I/O function.
		P4MODSEL = p4modsel_set.reg;
	}
	/* P4FNCSEL: P4 Port Function Select Register */
	{
		p4fncsel_set.reg = P4FNCSEL;
		p4fncsel_set.bit.P43MUX	= 0;		/// - P43 : UPMUX.
		p4fncsel_set.bit.P42MUX	= 0;		/// - P42 : UPMUX.
		p4fncsel_set.bit.P41MUX	= 0;		/// - P41 : UPMUX.
		p4fncsel_set.bit.P40MUX	= 0;		/// - P40 : UPMUX.
		P4FNCSEL = p4fncsel_set.reg;
	}
#if defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04)
	/// Assign the RFC CH.1 output function to the port.
	/*
	 * P02:RFCLKO1
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P0MODSEL: P0 Port Mode Select Register */
		{
			/// P0 Port Mode Select Register
			p0modsel_set.reg = P0MODSEL;
			p0modsel_set.bit.P02SEL = 1;		/// - P02 : Enable peripheral I/O function.
			P0MODSEL = p0modsel_set.reg;
		}
		/* P0FNCSEL: P0 Port Function Select Register */
		{
			p0fncsel_set.reg = P0FNCSEL;
			p0fncsel_set.bit.P02MUX	= 0;		/// - P02 : UPMUX.
			P0FNCSEL = p0fncsel_set.reg;
		}
	}
#endif
#if defined(C17_MCUSEL_W16)
	/// Assign the RFC CH.1 output function to the port.
	/*
	 * P31:RFCLKO1
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P3MODSEL: P3 Port Mode Select Register */
		{
			/// P3 Port Mode Select Register
			p3modsel_set.reg = P3MODSEL;
			p3modsel_set.bit.P31SEL = 1;		/// - P31 : Enable peripheral I/O function.
			P3MODSEL = p3modsel_set.reg;
		}
		/* P3FNCSEL: P3 Port Function Select Register */
		{
			p3fncsel_set.reg = P3FNCSEL;
			p3fncsel_set.bit.P31MUX	= 0;		/// - P31 : UPMUX.
			P3FNCSEL = p3fncsel_set.reg;
		}
	}
#endif
#endif
#if defined(C17_MCUSEL_W15)
	/// Assign the RFC CH.1 input/output function to the ports.
    /*
     * P10:SENB1
     * P11:SENA1
     * P12:REF1
     * P13:REFIN1
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		/// P1 Port Mode Select Register
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P13SEL = 1;		/// - P13 : Enable peripheral I/O function.
		p1modsel_set.bit.P12SEL = 1;		/// - P12 : Enable peripheral I/O function.
		p1modsel_set.bit.P11SEL = 1;		/// - P11 : Enable peripheral I/O function.
		p1modsel_set.bit.P10SEL = 1;		/// - P10 : Enable peripheral I/O function.
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P13MUX	= 0;		/// - P13 : UPMUX.
		p1fncsel_set.bit.P12MUX	= 0;		/// - P12 : UPMUX.
		p1fncsel_set.bit.P11MUX	= 0;		/// - P11 : UPMUX.
		p1fncsel_set.bit.P10MUX	= 0;		/// - P10 : UPMUX.
		P1FNCSEL = p1fncsel_set.reg;
	}
#endif
#if defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
	/// Assign the RFC CH.1 input/output function to the ports.
    /*
     * P37:SENB1
     * P40:SENA1
     * P41:REF1
     * P42:REFIN1
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P3MODSEL: P3 Port Mode Select Register */
	{
		/// P3 Port Mode Select Register
		p3modsel_set.reg = P3MODSEL;
		p3modsel_set.bit.P37SEL = 1;		/// - P37 : Enable peripheral I/O function.
		P3MODSEL = p3modsel_set.reg;
	}
	/* P3FNCSEL: P3 Port Function Select Register */
	{
		p3fncsel_set.reg = P3FNCSEL;
		p3fncsel_set.bit.P37MUX	= 0;		/// - P37 : UPMUX.
		P3FNCSEL = p3fncsel_set.reg;
	}

	/// Set Universal Port Multiplexer (UPMUX).
	/* P4MODSEL: P4 Port Mode Select Register */
	{
		/// P4 Port Mode Select Register
		p4modsel_set.reg = P4MODSEL;
		p4modsel_set.bit.P42SEL = 1;		/// - P42 : Enable peripheral I/O function.
		p4modsel_set.bit.P41SEL = 1;		/// - P41 : Enable peripheral I/O function.
		p4modsel_set.bit.P40SEL = 1;		/// - P40 : Enable peripheral I/O function.
		P4MODSEL = p4modsel_set.reg;
	}
	/* P4FNCSEL: P4 Port Function Select Register */
	{
		p4fncsel_set.reg = P4FNCSEL;
		p4fncsel_set.bit.P42MUX	= 0;		/// - P42 : UPMUX.
		p4fncsel_set.bit.P41MUX	= 0;		/// - P41 : UPMUX.
		p4fncsel_set.bit.P40MUX	= 0;		/// - P40 : UPMUX.
		P4FNCSEL = p4fncsel_set.reg;
	}

	/// Assign the RFC CH.1 output function to the port.
	/*
	 * P05:RFCLKO1
	 */
	if(outclk == 0) {
		/// Set Universal Port Multiplexer (UPMUX).
		/* P0MODSEL: P0 Port Mode Select Register */
		{
			/// P0 Port Mode Select Register
			p0modsel_set.reg = P0MODSEL;
			p0modsel_set.bit.P05SEL = 1;		/// - P05 : Enable peripheral I/O function.
			P0MODSEL = p0modsel_set.reg;
		}
		/* P0FNCSEL: P0 Port Function Select Register */
		{
			p0fncsel_set.reg = P0FNCSEL;
			p0fncsel_set.bit.P05MUX	= 0;		/// - P05 : UPMUX.
			P0FNCSEL = p0fncsel_set.reg;
		}
	}
#endif
}
#endif


#if defined(C17_MCUSEL_W15)
/************************************************************************//**
 * @brief   Setting Port(GPIO) for RFC CH.2.
 *
 * @param   outclk   RFCCLKO2 enable(0)/disable(1).
 *
 * @retval  none
 ***************************************************************************/
static void setRfcPortCh2(unsigned short outclk)
{
	P2MODSEL_REG	p2modsel_set;
	P2FNCSEL_REG	p2fncsel_set;

	/// Assign the RFC CH.2 input/output function to the ports.
    /*
     * P20:SENB2
     * P21:SENA2
     * P22:REF2
     * P23:REFIN2
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P2MODSEL: P2 Port Mode Select Register */
	{
		/// P2 Port Mode Select Register
		p2modsel_set.reg = P2MODSEL;
		p2modsel_set.bit.P23SEL = 1;		/// - P23 : Enable peripheral I/O function.
		p2modsel_set.bit.P22SEL = 1;		/// - P22 : Enable peripheral I/O function.
		p2modsel_set.bit.P21SEL = 1;		/// - P21 : Enable peripheral I/O function.
		p2modsel_set.bit.P20SEL = 1;		/// - P20 : Enable peripheral I/O function.
		P2MODSEL = p2modsel_set.reg;
	}
	/* P2FNCSEL: P2 Port Function Select Register */
	{
		p2fncsel_set.reg = P2FNCSEL;
		p2fncsel_set.bit.P23MUX	= 0;		/// - P23 : UPMUX.
		p2fncsel_set.bit.P22MUX	= 0;		/// - P22 : UPMUX.
		p2fncsel_set.bit.P21MUX	= 0;		/// - P21 : UPMUX.
		p2fncsel_set.bit.P20MUX	= 0;		/// - P20 : UPMUX.
		P2FNCSEL = p2fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_W15)
/************************************************************************//**
 * @brief   Setting Port(GPIO) for RFC CH.3.
 *
 * @param   outclk   RFCCLKO3 enable(0)/disable(1).
 *
 * @retval  none
 ***************************************************************************/
static void setRfcPortCh3(unsigned short outclk)
{
	P2MODSEL_REG	p2modsel_set;
	P2FNCSEL_REG	p2fncsel_set;

	/// Assign the RFC CH.3 input/output function to the ports.
    /*
     * P24:SENB3
     * P25:SENA3
     * P26:REF3
     * P27:REFIN3
     */
	/// Set Universal Port Multiplexer (UPMUX).
	/* P2MODSEL: P2 Port Mode Select Register */
	{
		/// P2 Port Mode Select Register
		p2modsel_set.reg = P2MODSEL;
		p2modsel_set.bit.P27SEL = 1;		/// - P27 : Enable peripheral I/O function.
		p2modsel_set.bit.P26SEL = 1;		/// - P26 : Enable peripheral I/O function.
		p2modsel_set.bit.P24SEL = 1;		/// - P25 : Enable peripheral I/O function.
		p2modsel_set.bit.P23SEL = 1;		/// - P24 : Enable peripheral I/O function.
		P2MODSEL = p2modsel_set.reg;
	}
	/* P2FNCSEL: P2 Port Function Select Register */
	{
		p2fncsel_set.reg = P2FNCSEL;
		p2fncsel_set.bit.P27MUX	= 0;		/// - P27 : UPMUX.
		p2fncsel_set.bit.P26MUX	= 0;		/// - P26 : UPMUX.
		p2fncsel_set.bit.P25MUX	= 0;		/// - P25 : UPMUX.
		p2fncsel_set.bit.P24MUX	= 0;		/// - P24 : UPMUX.
		P2FNCSEL = p2fncsel_set.reg;
	}
}
#endif


/************************************************************************//**
 * @brief   Start RFC.
 *
 * @param   rfcChannel              RFC CH.
 *  @li @c   0 to CH_MAX_COUNT-1rfcChannel
 *
 * @retval  none
 ***************************************************************************/
void c17startRfc(unsigned short rfcChannel)
{
	RFCNCTL_REG			rfcnctl_set;
	RFCNINTF_REG		rfcnintf_set;

	/// clear interrupt flag
	/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
	{
		rfcnintf_set.reg = 0;
		rfcnintf_set.bit.OVTCIF  = 1;
		rfcnintf_set.bit.OVMCIF  = 1;
		rfcnintf_set.bit.ESENBIF = 1;
		rfcnintf_set.bit.ESENAIF = 1;
		rfcnintf_set.bit.EREFIF  = 1;
		rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
	}

	/// Start RFC.
	/* RFCNCTL_REG: RFC Ch.N Control Register */
	{
		rfcnctl_set.reg = rfcnctl_table[rfcChannel]->reg;
		rfcnctl_set.bit.MODEN  = 1;
		rfcnctl_table[rfcChannel]->reg = rfcnctl_set.reg;
	}

}


/************************************************************************//**
 * @brief   Stop RFC.
 *
 * @param   rfcChannel              RFC CH.
 *  @li @c   0 to CH_MAX_COUNT-1rfcChannel
 *
 * @retval  none
 ***************************************************************************/
void c17stopRfc(unsigned short rfcChannel)
{
	RFCNCTL_REG			rfcnctl_set;

	/// Stop RFC.
	/* RFCNCTL_REG: RFC Ch.N Control Register */
	{
		rfcnctl_set.reg = rfcnctl_table[rfcChannel]->reg;
		rfcnctl_set.bit.MODEN  = 0;
		rfcnctl_table[rfcChannel]->reg = rfcnctl_set.reg;
	}

	/// Disable interrupt.
	c17disableIntRfc(rfcChannel);

}


/************************************************************************//**
 * @brief   Set measurement counter data.
 *
 * @param   rfcChannel  RFC Channel
 * @param   count       Measurement counter data.
 *
 * @retval  none
 ***************************************************************************/
void c17setRfcMeasurementCounter(unsigned short rfcChannel, unsigned long count)
{
	/// Set measurement counter data.
	rfcnmcl_table[rfcChannel]->reg = (unsigned short)((count >>  0) & 0xFFFF);
	rfcnmch_table[rfcChannel]->reg = (unsigned short)((count >> 16) & 0x00FF);
}


/************************************************************************//**
 * @brief	Get measurement counter data.
 *
 * @param   rfcChannel  RFC Channel
 *
 * @retval  Measurement counter data.
 ***************************************************************************/
unsigned long c17getRfcMeasurementCounter(unsigned short rfcChannel)
{
	unsigned long result = 0;

	/// Get measurement counter data.
	result = ((unsigned long)(rfcnmch_table[rfcChannel]->reg & 0x00FF ) << 16);
	result = result | rfcnmcl_table[rfcChannel]->reg;

	return result;
}


/************************************************************************//**
 * @brief   Set Time base counter data.
 *
 * @param   rfcChannel  RFC Channel
 * @param   count       Time base counter data.
 *
 * @retval  none
 ***************************************************************************/
void c17setRfcTimeBaseCounter(unsigned short rfcChannel, unsigned long count)
{
	/// Set Time base counter data.
	rfcntcl_table[rfcChannel]->reg = (unsigned short)((count >>  0) & 0xFFFF);
	rfcntch_table[rfcChannel]->reg = (unsigned short)((count >> 16) & 0x00FF);
}


/************************************************************************//**
 * @brief   Get Time base counter data.
 *
 * @param   rfcChannel     RFC Channel
 *
 * @return  Time base counter data.
 ***************************************************************************/
unsigned long c17getRfcTimeBaseCounter(unsigned short rfcChannel)
{
	unsigned long result = 0;

	/// Get Time base counter data.
	result = ((unsigned long)(rfcntcl_table[rfcChannel]->reg & 0x00FF) << 16);
	result = result | rfcntch_table[rfcChannel]->reg;

	return result;
}


/************************************************************************//**
 * @brief   RFC Converting Operations.
 *
 * @param   rfcChannel      RFC Channel
 * @param   startCount      Start measurement count.
 * @param   sensorCount     Pointer variable that stores measurement counter.
 *
 * @retval  RFC_STS_CONV_SEN_A      Sensor A oscillation completion interrupt.
 * @retval  RFC_STS_CONV_ERR_OVTC   Time base counter overflow error.
 * @retval  RFC_STS_CONV_ERR_OVMC   Measurement counter overflow error.
 ***************************************************************************/
int c17runRfcConvertingOperationSenA(unsigned short rfcChannel, unsigned long startCount, unsigned long* sensorCount)
{
	RFCNTRG_REG			rfcntrg_set;
	RFCNINTF_REG		rfcnintf_set;

	int result = RFC_STS_CONV_ERR_OVMC;

	/// Set measurement counter data.
	c17setRfcMeasurementCounter(rfcChannel, startCount);
	/// Set Time base counter data.
	c17setRfcTimeBaseCounter(rfcChannel, 0x00000000);

	/// Clear interrupt flag.
	/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
	{
		rfcnintf_set.reg = 0;
		rfcnintf_set.bit.OVTCIF  = 1;
		rfcnintf_set.bit.EREFIF  = 1;
		rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
	}

	/// Start CR oscillation.
	/* RFCNTRG_REG: RFC Ch.N Oscillation Trigger Register */
	{
		rfcntrg_set.reg = rfcntrg_table[rfcChannel]->reg;
		rfcntrg_set.bit.SREF  = 1;
		rfcntrg_table[rfcChannel]->reg = rfcntrg_set.reg;
	}

	/**
	 * Wait Reference oscillation completion Interrupt.
	 * @todo Add time-out processing as needed.
	 */
	while(rfcnintf_table[rfcChannel]->bit.EREFIF == 0) {
		/// Time base counter overflow error.
		if(rfcnintf_table[rfcChannel]->bit.OVTCIF == 1) {

			/// Clear interrupt flag
			/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
			{
				rfcnintf_set.reg = rfcnintf_table[rfcChannel]->reg;
				rfcnintf_set.bit.OVTCIF  = 1;
				rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
			}
			return RFC_STS_CONV_ERR_OVTC;
		}
	}

	/// Clear interrupt flag.
	/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
	{
		rfcnintf_set.reg = rfcnintf_table[rfcChannel]->reg;
		rfcnintf_set.bit.OVTCIF  = 1;
		rfcnintf_set.bit.ESENAIF  = 1;
		rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
	}


	/// Start Sensor A oscillation.
	/* RFCNTRG_REG: RFC Ch.N Oscillation trigger Register */
	{
		rfcntrg_set.reg = rfcntrg_table[rfcChannel]->reg;
		rfcntrg_set.bit.SSENA  = 1;
		rfcntrg_table[rfcChannel]->reg = rfcntrg_set.reg;
	}

	/**
	 * Wait Sensor A oscillation completion Interrupt.
	 * @todo Add time-out processing as needed.
	 */
	while(1) {
		/// Sensor A oscillation completion interrupt.
		if(rfcnintf_table[rfcChannel]->bit.ESENAIF == 1) {

			/// Clear interrupt flag.
			/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
			{
				rfcnintf_set.reg = rfcnintf_table[rfcChannel]->reg;
				rfcnintf_set.bit.ESENAIF  = 1;
				rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
			}

			*sensorCount = c17getRfcMeasurementCounter(rfcChannel);
			result = RFC_STS_CONV_SEN_A;
			break;
		}
		/// Measurement counter overflow error.
		if(rfcnintf_table[rfcChannel]->bit.OVMCIF == 1) {

			/// Clear interrupt flag.
			/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
			{
				rfcnintf_set.reg = rfcnintf_table[rfcChannel]->reg;
				rfcnintf_set.bit.OVMCIF  = 1;
				rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
			}

			result = RFC_STS_CONV_ERR_OVMC;
			break;
		}
	}

	return result;
}


/************************************************************************//**
 * @brief   RFC Converting Operations.
 *
 * @param   rfcChannel      RFC Channel
 * @param   startCount      Start measurement count.
 * @param   sensorCount     Pointer variable that stores measurement counter.
 *
 * @retval  RFC_STS_CONV_SEN_B      Sensor B oscillation completion interrupt.
 * @retval  RFC_STS_CONV_ERR_OVTC   Time base counter overflow error.
 * @retval  RFC_STS_CONV_ERR_OVMC   Measurement counter overflow error.
 ***************************************************************************/
int c17runRfcConvertingOperationSenB(unsigned short rfcChannel, unsigned long startCount, unsigned long* sensorCount)
{
	RFCNTRG_REG			rfcntrg_set;
	RFCNINTF_REG		rfcnintf_set;

	int result = RFC_STS_CONV_ERR_OVMC;

	/// Set measurement counter data.
	c17setRfcMeasurementCounter(rfcChannel, startCount);
	/// Set Time base counter data.
	c17setRfcTimeBaseCounter(rfcChannel, 0x00000000);

	/// Clear interrupt flag.
	/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
	{
		rfcnintf_set.reg = 0;
		rfcnintf_set.bit.OVTCIF  = 1;
		rfcnintf_set.bit.EREFIF  = 1;
		rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
	}

	/// Start CR oscillation.
	/* RFCNTRG_REG: RFC Ch.N Oscillation Trigger Register */
	{
		rfcntrg_set.reg = rfcntrg_table[rfcChannel]->reg;
		rfcntrg_set.bit.SREF  = 1;
		rfcntrg_table[rfcChannel]->reg = rfcntrg_set.reg;
	}

	/**
	 * Wait Reference oscillation completion Interrupt.
	 * @todo Add time-out processing as needed.
	 */
	while(rfcnintf_table[rfcChannel]->bit.EREFIF == 0) {
		/// Time base counter overflow error.
		if(rfcnintf_table[rfcChannel]->bit.OVTCIF == 1) {

			/// Clear interrupt flag
			/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
			{
				rfcnintf_set.reg = rfcnintf_table[rfcChannel]->reg;
				rfcnintf_set.bit.OVTCIF  = 1;
				rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
			}
			return RFC_STS_CONV_ERR_OVTC;
		}
	}

	/// Clear interrupt flag.
	/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
	{
		rfcnintf_set.reg = rfcnintf_table[rfcChannel]->reg;
		rfcnintf_set.bit.OVTCIF  = 1;
		rfcnintf_set.bit.ESENBIF  = 1;
		rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
	}


	/// Start Sensor B oscillation.
	/* RFCNTRG_REG: RFC Ch.N Oscillation trigger Register */
	{
		rfcntrg_set.reg = rfcntrg_table[rfcChannel]->reg;
		rfcntrg_set.bit.SSENB  = 1;
		rfcntrg_table[rfcChannel]->reg = rfcntrg_set.reg;
	}

	/**
	 * Wait Sensor B oscillation completion Interrupt.
	 * @todo Add time-out processing as needed.
	 */
	while(1) {
		/// Sensor B oscillation completion interrupt.
		if(rfcnintf_table[rfcChannel]->bit.ESENBIF == 1) {

			/// Clear interrupt flag.
			/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
			{
				rfcnintf_set.reg = rfcnintf_table[rfcChannel]->reg;
				rfcnintf_set.bit.ESENBIF  = 1;
				rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
			}

			*sensorCount = c17getRfcMeasurementCounter(rfcChannel);
			result = RFC_STS_CONV_SEN_B;
			break;
		}
		/// Measurement counter overflow error.
		if(rfcnintf_table[rfcChannel]->bit.OVMCIF == 1) {

			/// Clear interrupt flag.
			/* RFCNINTF_REG: RFC Ch.N Interrupt Flag Register */
			{
				rfcnintf_set.reg = rfcnintf_table[rfcChannel]->reg;
				rfcnintf_set.bit.OVMCIF  = 1;
				rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;
			}

			result = RFC_STS_CONV_ERR_OVMC;
			break;
		}
	}

	return result;
}


/************************************************************************//**
 * @brief   RFC Interrupt enable.
 *
 * @param   rfcChannel  RFC CH.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntRfc(unsigned short rfcChannel)
{
	RFCNINTF_REG	rfcnintf_set;
	RFCNINTE_REG	rfcninte_set;

	if(rfcChannel >= CH_MAX_COUNT) {
		return;
	}

	/* RFCNINTF:RFC Ch.N Interrupt Flag Register */
	{
		rfcnintf_set.reg = 0;
		rfcnintf_set.bit.OVTCIF = 1;
		rfcnintf_set.bit.OVMCIF = 1;
		rfcnintf_set.bit.ESENBIF = 1;
		rfcnintf_set.bit.ESENAIF = 1;
		rfcnintf_set.bit.EREFIF = 1;
		rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;		///- Clear interrupt flag.
	}

	/* RFCNINTE: RFC Ch.N Interrupt Enable Register */
    /**
     * @todo Change setting interrupt enable.
     */
	{
		rfcninte_set.reg = 0;
		rfcninte_set.bit.OVTCIE = 1;
		rfcninte_set.bit.OVMCIE = 1;
		rfcninte_set.bit.ESENBIE = 1;
		rfcninte_set.bit.ESENAIE = 1;
		rfcninte_set.bit.EREFIE = 1;
		rfcninte_table[rfcChannel]->reg = rfcninte_set.reg;		///- Enable interrupt.
	}
}


/************************************************************************//**
 * @brief   RFC Interrupt disable.
 *
 * @param   rfcChannel  RFC CH.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntRfc(unsigned short rfcChannel)
{
	RFCNINTF_REG	rfcnintf_set;
	RFCNINTE_REG	rfcninte_set;

	if(rfcChannel >= CH_MAX_COUNT) {
		return;
	}

	/* RFCNINTF:RFC Ch.N Interrupt Flag Register */
	{
		rfcnintf_set.reg = 0;
		rfcnintf_set.bit.OVTCIF = 1;
		rfcnintf_set.bit.OVMCIF = 1;
		rfcnintf_set.bit.ESENBIF = 1;
		rfcnintf_set.bit.ESENAIF = 1;
		rfcnintf_set.bit.EREFIF = 1;
		rfcnintf_table[rfcChannel]->reg = rfcnintf_set.reg;		///- Clear interrupt flag.
	}

	/* RFCNINTE: RFC Ch.N Interrupt Enable Register */
	{
		rfcninte_set.reg = 0;
		rfcninte_set.bit.OVTCIE = 0;
		rfcninte_set.bit.OVMCIE = 0;
		rfcninte_set.bit.ESENBIE = 0;
		rfcninte_set.bit.ESENAIE = 0;
		rfcninte_set.bit.EREFIE = 0;
		rfcninte_table[rfcChannel]->reg = rfcninte_set.reg;		///- Disable interrupt.
	}
}


/************************************************************************//**
 * @brief   RFC CH.0 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intRfcCh0(void)
{
	RFCNINTF_REG	rfc0intf_set;

	/* RFCNINTF:RFC Ch.N Interrupt Flag read & clear */
	{
		rfc0intf_set.reg = RFC0INTF;
		RFC0INTF = rfc0intf_set.reg;
	}

	/// Check interrupt cause occurrence status.

	if(rfc0intf_set.bit.OVTCIF == 1) {

	   /**
		* @todo add interrupt function of Time base counter overflow error.
		*/
	}

	if(rfc0intf_set.bit.OVMCIF == 1) {

	   /**
		* @todo add interrupt function of Measurement counter overflow error.
		*/
	}

	if(rfc0intf_set.bit.ESENBIF == 1) {

	   /**
		* @todo add interrupt function of Sensor B oscillation completion.
		*/
	}

	if(rfc0intf_set.bit.ESENAIF == 1) {

	   /**
		* @todo add interrupt function of Sensor A oscillation completion.
		*/
	}

	if(rfc0intf_set.bit.EREFIF == 1) {

	   /**
		* @todo add interrupt function of Reference oscillation completion.
		*/
	}

}


#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M25)
/************************************************************************//**
 * @brief   RFC CH.1 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intRfcCh1(void)
{
	RFCNINTF_REG	rfc1intf_set;

	/* RFCNINTF:RFC Ch.N Interrupt Flag read & clear */
	{
		rfc1intf_set.reg = RFC1INTF;
		RFC1INTF = rfc1intf_set.reg;
	}

	/// Check interrupt cause occurrence status.

	if(rfc1intf_set.bit.OVTCIF == 1) {

	   /**
		* @todo add interrupt function of Time base counter overflow error.
		*/
	}

	if(rfc1intf_set.bit.OVMCIF == 1) {

	   /**
		* @todo add interrupt function of Measurement counter overflow error.
		*/
	}

	if(rfc1intf_set.bit.ESENBIF == 1) {

	   /**
		* @todo add interrupt function of Sensor B oscillation completion.
		*/
	}

	if(rfc1intf_set.bit.ESENAIF == 1) {

	   /**
		* @todo add interrupt function of Sensor A oscillation completion.
		*/
	}

	if(rfc1intf_set.bit.EREFIF == 1) {

	   /**
		* @todo add interrupt function of Reference oscillation completion.
		*/
	}

}
#endif


#if defined(C17_MCUSEL_W15)
/************************************************************************//**
 * @brief   RFC CH.2 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intRfcCh2(void)
{
	RFCNINTF_REG	rfc2intf_set;

	/* RFCNINTF:RFC Ch.N Interrupt Flag read & clear */
	{
		rfc2intf_set.reg = RFC2INTF;
		RFC2INTF = rfc2intf_set.reg;
	}

	/// Check interrupt cause occurrence status.

	if(rfc2intf_set.bit.OVTCIF == 1) {

	   /**
		* @todo add interrupt function of Time base counter overflow error.
		*/
	}

	if(rfc2intf_set.bit.OVMCIF == 1) {

	   /**
		* @todo add interrupt function of Measurement counter overflow error.
		*/
	}

	if(rfc2intf_set.bit.ESENBIF == 1) {

	   /**
		* @todo add interrupt function of Sensor B oscillation completion.
		*/
	}

	if(rfc2intf_set.bit.ESENAIF == 1) {

	   /**
		* @todo add interrupt function of Sensor A oscillation completion.
		*/
	}

	if(rfc2intf_set.bit.EREFIF == 1) {

	   /**
		* @todo add interrupt function of Reference oscillation completion.
		*/
	}

}
#endif


#if defined(C17_MCUSEL_W15)
/************************************************************************//**
 * @brief   RFC CH.3 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intRfcCh3(void)
{
	RFCNINTF_REG	rfc3intf_set;

	/* RFCNINTF:RFC Ch.N Interrupt Flag read & clear */
	{
		rfc3intf_set.reg = RFC3INTF;
		RFC3INTF = rfc3intf_set.reg;
	}

	/// Check interrupt cause occurrence status.

	if(rfc3intf_set.bit.OVTCIF == 1) {

	   /**
		* @todo add interrupt function of Time base counter overflow error.
		*/
	}

	if(rfc3intf_set.bit.OVMCIF == 1) {

	   /**
		* @todo add interrupt function of Measurement counter overflow error.
		*/
	}

	if(rfc3intf_set.bit.ESENBIF == 1) {

	   /**
		* @todo add interrupt function of Sensor B oscillation completion.
		*/
	}

	if(rfc3intf_set.bit.ESENAIF == 1) {

	   /**
		* @todo add interrupt function of Sensor A oscillation completion.
		*/
	}

	if(rfc3intf_set.bit.EREFIF == 1) {

	   /**
		* @todo add interrupt function of Reference oscillation completion.
		*/
	}

}
#endif

#endif

