/************************************************************************//**
 *
 * @file    main.c
 *
 * @brief   This is RFC sample program.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *           - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
/************************************************************************//**
 * @mainpage   S1C17W34/W35/W36 R/F Converter (RFC)
 *
 * @section     intro Introduction
 * Converts the sensor resistance into a digital value by performing CR
 * oscillation and counting the oscillation clock.
 *
 * @subsection  --- S1C17W34/W35/W36 ---
 * @subsection	step0   Step 0: Initialize and start OSC1.
 * @subsection	step1   Step 1: The system clock set in OSC1.
 * @subsection	step2   Step 2: Initialize RFC.
 * @subsection	step3   Step 3: Run RFC and get measurement counter (sensor A).
 * @subsection	step4   Step 4: Stop RFC.
 * @subsection	step5   Step 5: Run RFC and get measurement counter (sensor B).
 * @subsection	step6   Step 6: Stop RFC.
 *
 * @section     install Installation
 * Start the IDE and import the "s1c17w34_w35_w36_sample" project.
 *
 ***************************************************************************/
#include <stdlib.h>
#include <stdio.h>
#include "crt0.h"
#include "c17_misc.h"
#include "c17_clg.h"
#include "c17_rfc.h"
#include "c17_init_config.h"

#if defined(C17_PE_RFC)

/* --- global variable --- */

int main_rfc(void);

/************************************************************************//**
 * main function.
 *
 * @brief   1. RFC register is initialized.
 *          2. Run RFC and get measurement counter (sensor A).
 *          3. Stop RFC
 *          4. Run RFC and get measurement counter (sensor B).
 *          5. Stop RFC
 *
 * @return  EXIT_SUCCESS    Success.
 * @return  EXIT_FAILURE    Failed.
 ***************************************************************************/
int main_rfc(void)
{
	int status;
	unsigned long count = 0;
	int result = 0;


	/// Clock = OSC1
	c17startClgOSC1();
	c17switchClgSystemClockOSC1();

	/// Initialize RFC.
	c17initRfc();

	/// Start RFC CH.0
	c17startRfc(RFC_CH_0);

	/// Run RFC CH.0 (sensor A) and get measurement counter.
	status = c17runRfcConvertingOperationSenA(RFC_CH_0, (unsigned long)0x00fc0000 , &count);
	if(status == RFC_STS_CONV_SEN_A) {
		result = EXIT_SUCCESS;
	} else {
		result = EXIT_FAILURE;
	}

	/// Stop RFC CH.0
	c17stopRfc(RFC_CH_0);
	/// clear time base counter
	c17setRfcTimeBaseCounter(RFC_CH_0, 0);
	/// clear measurement counter
	c17setRfcMeasurementCounter(RFC_CH_0, 0);

	/// Start RFC CH.0
	c17startRfc(RFC_CH_0);

	/// Run RFC CH.0 (sensor B) and get measurement counter.
	status = c17runRfcConvertingOperationSenB(RFC_CH_0, (unsigned long)0x00fc0000 , &count);
	if(status == RFC_STS_CONV_SEN_B) {
		result = EXIT_SUCCESS;
	} else {
		result = EXIT_FAILURE;
	}

	/// Stop RFC CH.0
	c17stopRfc(RFC_CH_0);

	/// Finish RFC demonstration.
	return result;
}
#endif

