/************************************************************************//**
 *
 * @file    c17w3x_reg.h
 *
 * @brief   The definition of S1C17W3x's register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2018-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Nov. 2018    1.00
 *              - First revision.
 *
 ******************************************************************************/
#ifndef C17W3X_REG_H__
#define C17W3X_REG_H__

#ifdef __cplusplus
extern "C" {
#endif


// Peripheral Register Header files
#include "reg/misc_reg.h"
#include "reg/pwg2_reg.h"
#include "reg/clg_w34_w35_w36_reg.h"
#include "reg/itc_w34_w35_w36_reg.h"
#include "reg/wdt2_reg.h"
#include "reg/rtca2_reg.h"
#include "reg/svd_reg.h"
#include "reg/t16_reg.h"
#include "reg/flashc_reg.h"
#include "reg/pport_w34_w35_w36_reg.h"
#include "reg/upmux_w34_w35_w36_reg.h"
#include "reg/uart2_reg.h"
#include "reg/spia_reg.h"
#include "reg/i2c_reg.h"
#include "reg/t16b_reg.h"
#include "reg/snda_reg.h"
#include "reg/remc2_reg.h"
#include "reg/lcd32b_reg.h"
#include "reg/rfc_reg.h"
#include "reg/adc12a_reg.h"
#include "reg/tsrvr_reg.h"


// Peripheral Register Base Address
#define MISC_REG_BASE_ADDR      0x4000      ///< MISC Register Base Address.
#define PWG2_REG_BASE_ADDR      0x4020      ///< PWG2 Register Base Address.
#define CLG_REG_BASE_ADDR       0x4040      ///< CLG Register Base Address.
#define ITC_REG_BASE_ADDR       0x4080      ///< ITC Register Base Address.
#define WDT2_REG_BASE_ADDR      0x40A0      ///< WDT2 Register Base Address.
#define RTCA2_REG_BASE_ADDR     0x40C0      ///< RTCA2 Register Base Address.
#define SVD_REG_BASE_ADDR       0x4100      ///< SVD Register Base Address.
#define T16_0_REG_BASE_ADDR     0x4160      ///< T16_0 Register Base Address.
#define T16_1_REG_BASE_ADDR     0x43A0      ///< T16_1 Register Base Address.
#define T16_2_REG_BASE_ADDR     0x5260      ///< T16_2 Register Base Address.
#define T16_3_REG_BASE_ADDR     0x5480      ///< T16_3 Register Base Address.
#define FLASHC_REG_BASE_ADDR    0x41B0      ///< FLASHC Register Base Address.
#define PPORT_REG_BASE_ADDR     0x4200      ///< PPORT Register Base Address.
#define UPMUX_REG_BASE_ADDR     0x4300      ///< UPMUX Register Base Address.
#define UART2_0_REG_BASE_ADDR   0x4380      ///< UART2_0 Register Base Address.
#define UART2_1_REG_BASE_ADDR   0x5200      ///< UART2_1 Register Base Address.
#define SPIA_0_REG_BASE_ADDR    0x43B0      ///< SPIA_0 Register Base Address.
#define SPIA_1_REG_BASE_ADDR    0x5270      ///< SPIA_1 Register Base Address.
#define I2C_0_REG_BASE_ADDR     0x43C0      ///< I2C_0 Register Base Address.
#define T16B_0_REG_BASE_ADDR    0x5000      ///< T16B_0 Register Base Address.
#define T16B_1_REG_BASE_ADDR    0x5040      ///< T16B_1 Register Base Address.
#define T16B_2_REG_BASE_ADDR    0x5080      ///< T16B_2 Register Base Address.
#define SNDA_REG_BASE_ADDR      0x5300      ///< SNDA Register Base Address.
#define REMC2_REG_BASE_ADDR     0x5320      ///< REMC2 Register Base Address.
#define LCD32B_REG_BASE_ADDR    0x5400      ///< LCD32B Register Base Address.
#define RFC_0_REG_BASE_ADDR     0x5440      ///< RFC_0 Register Base Address.
#define RFC_1_REG_BASE_ADDR     0x5460      ///< RFC_1 Register Base Address.
#define ADC12A_0_REG_BASE_ADDR  0x54A2      ///< ADC12A_0 Register Base Address.
#define TSRVR_0_REG_BASE_ADDR   0x54C0      ///< TSRVR_0 Register Base Address.


// ----- C17W3X Registers -----

/// ----- MISC -----

/// MISC System Protect Register.
#define MSCPROT                 (*((volatile MSCPROT_REG *)(MISC_REG_BASE_ADDR + 0x00))).reg

/// MISC IRAM Size Register.
#define MSCIRAMSZ               (*((volatile MSCIRAMSZ_REG *)(MISC_REG_BASE_ADDR + 0x02))).reg

/// MISC Vector Table Address Low Register.
#define MSCTTBRL                (*((volatile MSCTTBRL_REG *)(MISC_REG_BASE_ADDR + 0x04))).reg

/// MISC Vector Table Address High Register.
#define MSCTTBRH                (*((volatile MSCTTBRH_REG *)(MISC_REG_BASE_ADDR + 0x06))).reg

/// MISC Vector Table Address Register.
#define MSCTTBR                 (*((volatile MSCTTBR_DWORD_REG *)(MISC_REG_BASE_ADDR + 0x04))).reg

/// MISC PSR Register.
#define MSCPSR                  (*((volatile MSCPSR_REG *)(MISC_REG_BASE_ADDR + 0x08))).reg

/// ----- PWG2 -----

/// PWG2 Control Register.
#define PWGCTL                  (*((volatile PWGCTL_REG *)(PWG2_REG_BASE_ADDR + 0x00))).reg

/// PWG2 Timing Control Register.
#define PWGTIM                  (*((volatile PWGTIM_REG *)(PWG2_REG_BASE_ADDR + 0x02))).reg

/// PWG2 Interrupt Flag Register.
#define PWGINTF                 (*((volatile PWGINTF_REG *)(PWG2_REG_BASE_ADDR + 0x04))).reg

/// PWG2 Interrupt Enable Register.
#define PWGINTE                 (*((volatile PWGINTE_REG *)(PWG2_REG_BASE_ADDR + 0x06))).reg

/// ----- CLG -----

/// CLG System Clock Control Register
#define CLGSCLK                 (*((volatile CLGSCLK_REG *)(CLG_REG_BASE_ADDR + 0x00))).reg

/// CLG Oscillation Control Register.
#define CLGOSC                  (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).reg

/// CLG IOSC Control Register.
#define CLGIOSC                 (*((volatile CLGIOSC_REG *)(CLG_REG_BASE_ADDR + 0x04))).reg

/// CLG OSC1 Control Register.
#define CLGOSC1                 (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).reg

/// CLG OSC3 Control Register.
#define CLGOSC3                 (*((volatile CLGOSC3_REG *)(CLG_REG_BASE_ADDR + 0x08))).reg

/// CLG Interrupt Flag Register.
#define CLGINTF                 (*((volatile CLGINTF_REG *)(CLG_REG_BASE_ADDR + 0x0C))).reg

/// CLG Interrupt Enable Register.
#define CLGINTE                 (*((volatile CLGINTE_REG *)(CLG_REG_BASE_ADDR + 0x0E))).reg

/// CLG FOUT0 Control Register.
#define CLGFOUT0                (*((volatile CLGFOUT0_REG *)(CLG_REG_BASE_ADDR + 0x10))).reg

/// CLG FOUT1 Control Register.
#define CLGFOUT1                (*((volatile CLGFOUT1_REG *)(CLG_REG_BASE_ADDR + 0x12))).reg

/// CLG Oscillation Frequency Trimming Register.
#define CLGTRIM                 (*((volatile CLGTRIM_REG *)(CLG_REG_BASE_ADDR + 0x14))).reg

/// ----- ITC -----

/// ITC Interrupt Level Setup Register 0
#define ITCLV0                  (*((volatile ITCLV0_REG *)(ITC_REG_BASE_ADDR + 0x00))).reg

/// ITC Interrupt Level Setup Register 1
#define ITCLV1                  (*((volatile ITCLV1_REG *)(ITC_REG_BASE_ADDR + 0x02))).reg

/// ITC Interrupt Level Setup Register 2
#define ITCLV2                  (*((volatile ITCLV2_REG *)(ITC_REG_BASE_ADDR + 0x04))).reg

/// ITC Interrupt Level Setup Register 3
#define ITCLV3                  (*((volatile ITCLV3_REG *)(ITC_REG_BASE_ADDR + 0x06))).reg

/// ITC Interrupt Level Setup Register 4
#define ITCLV4                  (*((volatile ITCLV4_REG *)(ITC_REG_BASE_ADDR + 0x08))).reg

/// ITC Interrupt Level Setup Register 5
#define ITCLV5                  (*((volatile ITCLV5_REG *)(ITC_REG_BASE_ADDR + 0x0A))).reg

/// ITC Interrupt Level Setup Register 6
#define ITCLV6                  (*((volatile ITCLV6_REG *)(ITC_REG_BASE_ADDR + 0x0C))).reg

/// ITC Interrupt Level Setup Register 7
#define ITCLV7                  (*((volatile ITCLV7_REG *)(ITC_REG_BASE_ADDR + 0x0E))).reg

/// ITC Interrupt Level Setup Register 8
#define ITCLV8                  (*((volatile ITCLV8_REG *)(ITC_REG_BASE_ADDR + 0x10))).reg

/// ITC Interrupt Level Setup Register 9
#define ITCLV9                  (*((volatile ITCLV9_REG *)(ITC_REG_BASE_ADDR + 0x12))).reg

/// ITC Interrupt Level Setup Register 10
#define ITCLV10                 (*((volatile ITCLV10_REG *)(ITC_REG_BASE_ADDR + 0x14))).reg

/// ITC Interrupt Level Setup Register 11
#define ITCLV11                 (*((volatile ITCLV11_REG *)(ITC_REG_BASE_ADDR + 0x16))).reg

// Interrupt Level Registers.
#define ILVSVD                  (*((volatile ITCLV0_REG *)(ITC_REG_BASE_ADDR + 0x00))).byte_reg[0]        ///< Supply voltage detector interrupt.
#define ILVPPORT_0              (*((volatile ITCLV0_REG *)(ITC_REG_BASE_ADDR + 0x00))).byte_reg[1]        ///< Port interrupt.
#define ILVPWG2                 (*((volatile ITCLV1_REG *)(ITC_REG_BASE_ADDR + 0x02))).byte_reg[0]        ///< Power generator interrupt.
#define ILVCLG                  (*((volatile ITCLV1_REG *)(ITC_REG_BASE_ADDR + 0x02))).byte_reg[1]        ///< Clock generator interrupt.
#define ILVRTCA_0               (*((volatile ITCLV2_REG *)(ITC_REG_BASE_ADDR + 0x04))).byte_reg[0]        ///< Real-time clock interrupt.
#define ILVT16_0                (*((volatile ITCLV2_REG *)(ITC_REG_BASE_ADDR + 0x04))).byte_reg[1]        ///< 16-bit timer Ch.0 interrupt.
#define ILVUART_0               (*((volatile ITCLV3_REG *)(ITC_REG_BASE_ADDR + 0x06))).byte_reg[0]        ///< UART Ch.0 interrupt.
#define ILVT16_1                (*((volatile ITCLV3_REG *)(ITC_REG_BASE_ADDR + 0x06))).byte_reg[1]        ///< 16-bit timer Ch.1 interrupt.
#define ILVSPIA_0               (*((volatile ITCLV4_REG *)(ITC_REG_BASE_ADDR + 0x08))).byte_reg[0]        ///< Synchronous serial interface Ch.0 interrupt.
#define ILVI2C_0                (*((volatile ITCLV4_REG *)(ITC_REG_BASE_ADDR + 0x08))).byte_reg[1]        ///< I2C Ch.0 interrupt.
#define ILVT16B_0               (*((volatile ITCLV5_REG *)(ITC_REG_BASE_ADDR + 0x0A))).byte_reg[0]        ///< 16-bit PWM timer Ch.0 interrupt.
#define ILVT16B_1               (*((volatile ITCLV5_REG *)(ITC_REG_BASE_ADDR + 0x0A))).byte_reg[1]        ///< 16-bit PWM timer Ch.1 interrupt.
#define ILVT16B_2               (*((volatile ITCLV6_REG *)(ITC_REG_BASE_ADDR + 0x0C))).byte_reg[0]        ///< 16-bit PWM timer Ch.2 interrupt.
#define ILVUART_1               (*((volatile ITCLV6_REG *)(ITC_REG_BASE_ADDR + 0x0C))).byte_reg[1]        ///< UART ch.1 interrupt.
#define ILVT16_2                (*((volatile ITCLV7_REG *)(ITC_REG_BASE_ADDR + 0x0E))).byte_reg[0]        ///< 16-bit timer Ch.2 interrupt.
#define ILVSPIA_1               (*((volatile ITCLV7_REG *)(ITC_REG_BASE_ADDR + 0x0E))).byte_reg[1]        ///< Synchronous serial interface Ch.1 interrupt.
#define ILVSNDA_0               (*((volatile ITCLV8_REG *)(ITC_REG_BASE_ADDR + 0x10))).byte_reg[0]        ///< Sound generator interrupt.
#define ILVREMC_0               (*((volatile ITCLV8_REG *)(ITC_REG_BASE_ADDR + 0x10))).byte_reg[1]        ///< IR remote controller interrupt.
#define ILVLCD32B               (*((volatile ITCLV9_REG *)(ITC_REG_BASE_ADDR + 0x12))).byte_reg[0]        ///< LCD driver interrupt.
#define ILVRFC_0                (*((volatile ITCLV9_REG *)(ITC_REG_BASE_ADDR + 0x12))).byte_reg[1]        ///< R/F converter Ch.0 interrupt.
#define ILVRFC_1                (*((volatile ITCLV10_REG *)(ITC_REG_BASE_ADDR + 0x14))).byte_reg[0]       ///< R/F converter Ch.1 interrupt.
#define ILVT16_3                (*((volatile ITCLV10_REG *)(ITC_REG_BASE_ADDR + 0x14))).byte_reg[1]       ///< 16-bit timer Ch.3 interrupt.
#define ILVADC12_0              (*((volatile ITCLV11_REG *)(ITC_REG_BASE_ADDR + 0x16))).byte_reg[0]       ///< 12-bit A/D converter Ch.0 interrupt.
#define ILVPPORT_1              (*((volatile ITCLV11_REG *)(ITC_REG_BASE_ADDR + 0x16))).byte_reg[1]       ///< P4-P5 Port interrupt.

/// ----- WDT2 -----

/// WDT2 Clock Control Register
#define WDTCLK                  (*((volatile WDTCLK_REG *)(WDT2_REG_BASE_ADDR + 0x00))).reg

/// WDT2 Control Register
#define WDTCTL                  (*((volatile WDTCTL_REG *)(WDT2_REG_BASE_ADDR + 0x02))).reg

/// WDT2 Counter Compare Match Register.
#define WDTCMP                  (*((volatile WDTCMP_REG *)(WDT2_REG_BASE_ADDR + 0x04))).reg

/// ----- RTCA2 -----

/// RTCA2 Control Register
#define RTCCTLL                 (*((volatile RTCCTLL_REG *)(RTCA2_REG_BASE_ADDR + 0x00))).reg

/// RTCA2 Control High Register
#define RTCCTLH                 (*((volatile RTCCTLH_REG *)(RTCA2_REG_BASE_ADDR + 0x01))).reg

/// RTCA2 Second Alarm Register
#define RTCALM1                 (*((volatile RTCALM1_REG *)(RTCA2_REG_BASE_ADDR + 0x02))).reg

/// RTCA2 Hour/Minute Alarm Register
#define RTCALM2                 (*((volatile RTCALM2_REG *)(RTCA2_REG_BASE_ADDR + 0x04))).reg

/// RTCA2 Stopwatch Control Register
#define RTCSWCTL                (*((volatile RTCSWCTL_REG *)(RTCA2_REG_BASE_ADDR + 0x06))).reg

/// RTCA2 main time zone Second/1[Hz] Register
#define RTCSEC1                 (*((volatile RTCSEC1_REG *)(RTCA2_REG_BASE_ADDR + 0x08))).reg

/// RTCA2 main time zone Hour/Minute Register
#define RTCHUR1                 (*((volatile RTCHUR1_REG *)(RTCA2_REG_BASE_ADDR + 0x0A))).reg

/// RTCA2 main time zone Month/Day Register
#define RTCMON1                 (*((volatile RTCMON1_REG *)(RTCA2_REG_BASE_ADDR + 0x0C))).reg

/// RTCA2 main time zone Year/Week Register
#define RTCYAR1                 (*((volatile RTCYAR1_REG *)(RTCA2_REG_BASE_ADDR + 0x0E))).reg

/// RTCA2 Interrupt Flag Register
#define RTCINTF                 (*((volatile RTCINTF_REG *)(RTCA2_REG_BASE_ADDR + 0x10))).reg

/// RTCA2 Interrupt Enable Register
#define RTCINTE                 (*((volatile RTCINTE_REG *)(RTCA2_REG_BASE_ADDR + 0x12))).reg

/// RTCA2 time zone 2 Second/1[Hz] Register
#define RTCSEC2                 (*((volatile RTCSEC2_REG *)(RTCA2_REG_BASE_ADDR + 0x18))).reg

/// RTCA2 time zone 2 Hour/Minute Register
#define RTCHUR2                 (*((volatile RTCHUR2_REG *)(RTCA2_REG_BASE_ADDR + 0x1A))).reg

/// RTCA2 time zone 2 Month/Day Register
#define RTCMON2                 (*((volatile RTCMON2_REG *)(RTCA2_REG_BASE_ADDR + 0x1C))).reg

/// RTCA2 time zone 2 Year/Week Register
#define RTCYAR2                 (*((volatile RTCYAR2_REG *)(RTCA2_REG_BASE_ADDR + 0x1E))).reg

/// RTCA2 time zone 3 Second/1[Hz] Register
#define RTCSEC3                 (*((volatile RTCSEC3_REG *)(RTCA2_REG_BASE_ADDR + 0x20))).reg

/// RTCA2 time zone 3 Hour/Minute Register
#define RTCHUR3                 (*((volatile RTCHUR3_REG *)(RTCA2_REG_BASE_ADDR + 0x22))).reg

/// RTCA2 time zone 3 Month/Day Register
#define RTCMON3                 (*((volatile RTCMON3_REG *)(RTCA2_REG_BASE_ADDR + 0x24))).reg

/// RTCA2 time zone 3 Year/Week Register
#define RTCYAR3                 (*((volatile RTCYAR3_REG *)(RTCA2_REG_BASE_ADDR + 0x26))).reg

/// ----- SVD -----

/// SVD Clock Control Register
#define SVDCLK                  (*((volatile SVDCLK_REG *)(SVD_REG_BASE_ADDR + 0x00))).reg

/// SVD Control Register
#define SVDCTL                  (*((volatile SVDCTL_REG *)(SVD_REG_BASE_ADDR + 0x02))).reg

/// SVD Status and Interrupt Flag Register
#define SVDINTF                 (*((volatile SVDINTF_REG *)(SVD_REG_BASE_ADDR + 0x04))).reg

/// SVD Interrupt Enable Register
#define SVDINTE                 (*((volatile SVDINTE_REG *)(SVD_REG_BASE_ADDR + 0x06))).reg

/// ----- T16 -----

/// T16 Ch.0 Clock Control Register
#define T16_0CLK                (*((volatile T16_NCLK_REG *)(T16_0_REG_BASE_ADDR + 0x00))).reg

/// T16 Ch.0 Mode Register
#define T16_0MOD                (*((volatile T16_NMOD_REG *)(T16_0_REG_BASE_ADDR + 0x02))).reg

/// T16 Ch.0 Control Register
#define T16_0CTL                (*((volatile T16_NCTL_REG *)(T16_0_REG_BASE_ADDR + 0x04))).reg

/// T16 Ch.0 Reload Data Register
#define T16_0TR                 (*((volatile T16_NTR_REG *)(T16_0_REG_BASE_ADDR + 0x06))).reg

/// T16 Ch.0 Counter Data Register
#define T16_0TC                 (*((volatile T16_NTC_REG *)(T16_0_REG_BASE_ADDR + 0x08))).reg

/// T16 Ch.0 Interrupt Flag Register
#define T16_0INTF               (*((volatile T16_NINTF_REG *)(T16_0_REG_BASE_ADDR + 0x0A))).reg

/// T16 Ch.0 Interrupt Enable Register
#define T16_0INTE               (*((volatile T16_NINTE_REG *)(T16_0_REG_BASE_ADDR + 0x0C))).reg

/// T16 Ch.1 Clock Control Register
#define T16_1CLK                (*((volatile T16_NCLK_REG *)(T16_1_REG_BASE_ADDR + 0x00))).reg

/// T16 Ch.1 Mode Register
#define T16_1MOD                (*((volatile T16_NMOD_REG *)(T16_1_REG_BASE_ADDR + 0x02))).reg

/// T16 Ch.1 Control Register
#define T16_1CTL                (*((volatile T16_NCTL_REG *)(T16_1_REG_BASE_ADDR + 0x04))).reg

/// T16 Ch.1 Reload Data Register
#define T16_1TR                 (*((volatile T16_NTR_REG *)(T16_1_REG_BASE_ADDR + 0x06))).reg

/// T16 Ch.1 Counter Data Register
#define T16_1TC                 (*((volatile T16_NTC_REG *)(T16_1_REG_BASE_ADDR + 0x08))).reg

/// T16 Ch.1 Interrupt Flag Register
#define T16_1INTF               (*((volatile T16_NINTF_REG *)(T16_1_REG_BASE_ADDR + 0x0A))).reg

/// T16 Ch.1 Interrupt Enable Register
#define T16_1INTE               (*((volatile T16_NINTE_REG *)(T16_1_REG_BASE_ADDR + 0x0C))).reg

/// T16 Ch.2 Clock Control Register
#define T16_2CLK                (*((volatile T16_NCLK_REG *)(T16_2_REG_BASE_ADDR + 0x00))).reg

/// T16 Ch.2 Mode Register
#define T16_2MOD                (*((volatile T16_NMOD_REG *)(T16_2_REG_BASE_ADDR + 0x02))).reg

/// T16 Ch.2 Control Register
#define T16_2CTL                (*((volatile T16_NCTL_REG *)(T16_2_REG_BASE_ADDR + 0x04))).reg

/// T16 Ch.2 Reload Data Register
#define T16_2TR                 (*((volatile T16_NTR_REG *)(T16_2_REG_BASE_ADDR + 0x06))).reg

/// T16 Ch.2 Counter Data Register
#define T16_2TC                 (*((volatile T16_NTC_REG *)(T16_2_REG_BASE_ADDR + 0x08))).reg

/// T16 Ch.2 Interrupt Flag Register
#define T16_2INTF               (*((volatile T16_NINTF_REG *)(T16_2_REG_BASE_ADDR + 0x0A))).reg

/// T16 Ch.2 Interrupt Enable Register
#define T16_2INTE               (*((volatile T16_NINTE_REG *)(T16_2_REG_BASE_ADDR + 0x0C))).reg

/// T16 Ch.3 Clock Control Register
#define T16_3CLK                (*((volatile T16_NCLK_REG *)(T16_3_REG_BASE_ADDR + 0x00))).reg

/// T16 Ch.3 Mode Register
#define T16_3MOD                (*((volatile T16_NMOD_REG *)(T16_3_REG_BASE_ADDR + 0x02))).reg

/// T16 Ch.3 Control Register
#define T16_3CTL                (*((volatile T16_NCTL_REG *)(T16_3_REG_BASE_ADDR + 0x04))).reg

/// T16 Ch.3 Reload Data Register
#define T16_3TR                 (*((volatile T16_NTR_REG *)(T16_3_REG_BASE_ADDR + 0x06))).reg

/// T16 Ch.3 Counter Data Register
#define T16_3TC                 (*((volatile T16_NTC_REG *)(T16_3_REG_BASE_ADDR + 0x08))).reg

/// T16 Ch.3 Interrupt Flag Register
#define T16_3INTF               (*((volatile T16_NINTF_REG *)(T16_3_REG_BASE_ADDR + 0x0A))).reg

/// T16 Ch.3 Interrupt Enable Register
#define T16_3INTE               (*((volatile T16_NINTE_REG *)(T16_3_REG_BASE_ADDR + 0x0C))).reg

/// ----- FLASHC -----

/// FLASHC Flash Read Cycle Register
#define FLASHCWAIT              (*((volatile FLASHCWAIT_REG *)(FLASHC_REG_BASE_ADDR + 0x00))).reg

/// ----- PPORT -----

/// P0 Port Data Register
#define P0DAT                   (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).reg

/// P0 Port Enable Register
#define P0IOEN                  (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).reg

/// P0 Port Pull-up/down Control Register
#define P0RCTL                  (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).reg

/// P0 Port Interrupt Flag Register
#define P0INTF                  (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).reg

/// P0 Port Interrupt Control Register
#define P0INTCTL                (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).reg

/// P0 Port Chattering Filter Enable Register
#define P0CHATEN                (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).reg

/// P0 Port Mode Select Register
#define P0MODSEL                (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).reg

/// P0 Port Function Select Register
#define P0FNCSEL                (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).reg

/// P1 Port Data Register
#define P1DAT                   (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).reg

/// P1 Port Enable Register
#define P1IOEN                  (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).reg

/// P1 Port Pull-up/down Control Register
#define P1RCTL                  (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).reg

/// P1 Port Interrupt Flag Register
#define P1INTF                  (*((volatile P1INTF_REG *)(PPORT_REG_BASE_ADDR + 0x16))).reg

/// P1 Port Interrupt Control Register
#define P1INTCTL                (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).reg

/// P1 Port Chattering Filter Enable Register
#define P1CHATEN                (*((volatile P1CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x1A))).reg

/// P1 Port Mode Select Register
#define P1MODSEL                (*((volatile P1MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1C))).reg

/// P1 Port Function Select Register
#define P1FNCSEL                (*((volatile P1FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1E))).reg

/// P2 Port Data Register
#define P2DAT                   (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).reg

/// P2 Port Enable Register
#define P2IOEN                  (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).reg

/// P2 Port Pull-up/down Control Register
#define P2RCTL                  (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).reg

/// P2 Port Interrupt Flag Register
#define P2INTF                  (*((volatile P2INTF_REG *)(PPORT_REG_BASE_ADDR + 0x26))).reg

/// P2 Port Interrupt Control Register
#define P2INTCTL                (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).reg

/// P2 Port Chattering Filter Enable Register
#define P2CHATEN                (*((volatile P2CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x2A))).reg

/// P2 Port Mode Select Register
#define P2MODSEL                (*((volatile P2MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2C))).reg

/// P2 Port Function Select Register
#define P2FNCSEL                (*((volatile P2FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2E))).reg

/// P3 Port Data Register
#define P3DAT                   (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).reg

/// P3 Port Enable Register
#define P3IOEN                  (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).reg

/// P3 Port Pull-up/down Control Register
#define P3RCTL                  (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).reg

/// P3 Port Interrupt Flag Register
#define P3INTF                  (*((volatile P3INTF_REG *)(PPORT_REG_BASE_ADDR + 0x36))).reg

/// P3 Port Interrupt Control Register
#define P3INTCTL                (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).reg

/// P3 Port Chattering Filter Enable Register
#define P3CHATEN                (*((volatile P3CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x3A))).reg

/// P3 Port Mode Select Register
#define P3MODSEL                (*((volatile P3MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3C))).reg

/// P3 Port Function Select Register
#define P3FNCSEL                (*((volatile P3FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3E))).reg

/// P4 Port Data Register
#define P4DAT                   (*((volatile P4DAT_REG *)(PPORT_REG_BASE_ADDR + 0x40))).reg

/// P4 Port Enable Register
#define P4IOEN                  (*((volatile P4IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x42))).reg

/// P4 Port Pull-up/down Control Register
#define P4RCTL                  (*((volatile P4RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x44))).reg

/// P4 Port Interrupt Flag Register
#define P4INTF                  (*((volatile P4INTF_REG *)(PPORT_REG_BASE_ADDR + 0x46))).reg

/// P4 Port Interrupt Control Register
#define P4INTCTL                (*((volatile P4INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x48))).reg

/// P4 Port Chattering Filter Enable Register
#define P4CHATEN                (*((volatile P4CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x4A))).reg

/// P5 Port Data Register
#define P5DAT                   (*((volatile P5DAT_REG *)(PPORT_REG_BASE_ADDR + 0x50))).reg

/// P5 Port Enable Register
#define P5IOEN                  (*((volatile P5IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x52))).reg

/// P5 Port Pull-up/down Control Register
#define P5RCTL                  (*((volatile P5RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x54))).reg

/// P5 Port Interrupt Flag Register
#define P5INTF                  (*((volatile P5INTF_REG *)(PPORT_REG_BASE_ADDR + 0x56))).reg

/// P5 Port Interrupt Control Register
#define P5INTCTL                (*((volatile P5INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x58))).reg

/// P5 Port Chattering Filter Enable Register
#define P5CHATEN                (*((volatile P5CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x5A))).reg

/// Pd Port Data Register
#define PDDAT                   (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).reg

/// Pd Port Enable Register
#define PDIOEN                  (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).reg

/// Pd Port Pull-up/down Control Register
#define PDRCTL                  (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).reg

/// Pd Port Mode Select Register
#define PDMODSEL                (*((volatile PDMODSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDC))).reg

/// Pd Port Function Select Register
#define PDFNCSEL                (*((volatile PDFNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDE))).reg

/// P Port Clock Control Register
#define PCLK                    (*((volatile PCLK_REG *)(PPORT_REG_BASE_ADDR + 0xE0))).reg

/// P Port Interrupt Flag Group Register
#define PINTFGRP                (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).reg

/// ----- UPMUX ----

/// P00-01 Universal Port Multiplexer Setting Register
#define P0UPMUX0                (*((volatile P0UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x00))).reg

/// P02-03 Universal Port Multiplexer Setting Register
#define P0UPMUX1                (*((volatile P0UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x02))).reg

/// P04-05 Universal Port Multiplexer Setting Register
#define P0UPMUX2                (*((volatile P0UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x04))).reg

/// P06-07 Universal Port Multiplexer Setting Register
#define P0UPMUX3                (*((volatile P0UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x06))).reg

/// P10-11 Universal Port Multiplexer Setting Register
#define P1UPMUX0                (*((volatile P1UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x08))).reg

/// P12-13 Universal Port Multiplexer Setting Register
#define P1UPMUX1                (*((volatile P1UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x0A))).reg

/// P14-15 Universal Port Multiplexer Setting Register
#define P1UPMUX2                (*((volatile P1UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x0C))).reg

/// P16-17 Universal Port Multiplexer Setting Register
#define P1UPMUX3                (*((volatile P1UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x0E))).reg

/// P20-21 Universal Port Multiplexer Setting Register
#define P2UPMUX0                (*((volatile P2UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x10))).reg

/// P22-23 Universal Port Multiplexer Setting Register
#define P2UPMUX1                (*((volatile P2UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x12))).reg

/// P24-25 Universal Port Multiplexer Setting Register
#define P2UPMUX2                (*((volatile P2UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x14))).reg

/// P26-27 Universal Port Multiplexer Setting Register
#define P2UPMUX3                (*((volatile P2UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x16))).reg

/// P30-31 Universal Port Multiplexer Setting Register
#define P3UPMUX0                (*((volatile P3UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x18))).reg

/// P32-33 Universal Port Multiplexer Setting Register
#define P3UPMUX1                (*((volatile P3UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x1A))).reg

/// P34-35 Universal Port Multiplexer Setting Register
#define P3UPMUX2                (*((volatile P3UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x1C))).reg

/// P36-37 Universal Port Multiplexer Setting Register
#define P3UPMUX3                (*((volatile P3UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x1E))).reg

/// ---- UART2 -----

/// UART2 Ch.0 Clock Control Register
#define UA0CLK                  (*((volatile UANCLK_REG *)(UART2_0_REG_BASE_ADDR + 0x00))).reg

/// UART2 Ch.0 Mode Register
#define UA0MOD                  (*((volatile UANMOD_REG *)(UART2_0_REG_BASE_ADDR + 0x02))).reg

/// UART2 Ch.0 Baud-Rate Register
#define UA0BR                   (*((volatile UANBR_REG *)(UART2_0_REG_BASE_ADDR + 0x04))).reg

/// UART2 Ch.0 Control Register
#define UA0CTL                  (*((volatile UANCTL_REG *)(UART2_0_REG_BASE_ADDR + 0x06))).reg

/// UART2 Ch.0 Transmit Data Register
#define UA0TXD                  (*((volatile UANTXD_REG *)(UART2_0_REG_BASE_ADDR + 0x08))).reg

/// UART2 Ch.0 Receive Data Register
#define UA0RXD                  (*((volatile UANRXD_REG *)(UART2_0_REG_BASE_ADDR + 0x0A))).reg

/// UART2 Ch.0 Status and Interrupt Flag Register
#define UA0INTF                 (*((volatile UANINTF_REG *)(UART2_0_REG_BASE_ADDR + 0x0C))).reg

/// UART2 Ch.0 Interrupt Enable Register
#define UA0INTE                 (*((volatile UANINTE_REG *)(UART2_0_REG_BASE_ADDR + 0x0E))).reg

/// UART2 Ch.1 Clock Control Register
#define UA1CLK                  (*((volatile UANCLK_REG *)(UART2_1_REG_BASE_ADDR + 0x00))).reg

/// UART2 Ch.1 Mode Register
#define UA1MOD                  (*((volatile UANMOD_REG *)(UART2_1_REG_BASE_ADDR + 0x02))).reg

/// UART2 Ch.1 Baud-Rate Register
#define UA1BR                   (*((volatile UANBR_REG *)(UART2_1_REG_BASE_ADDR + 0x04))).reg

/// UART2 Ch.1 Control Register
#define UA1CTL                  (*((volatile UANCTL_REG *)(UART2_1_REG_BASE_ADDR + 0x06))).reg

/// UART2 Ch.1 Transmit Data Register
#define UA1TXD                  (*((volatile UANTXD_REG *)(UART2_1_REG_BASE_ADDR + 0x08))).reg

/// UART2 Ch.1 Receive Data Register
#define UA1RXD                  (*((volatile UANRXD_REG *)(UART2_1_REG_BASE_ADDR + 0x0A))).reg

/// UART2 Ch.1 Status and Interrupt Flag Register
#define UA1INTF                 (*((volatile UANINTF_REG *)(UART2_1_REG_BASE_ADDR + 0x0C))).reg

/// UART2 Ch.1 Interrupt Enable Register
#define UA1INTE                 (*((volatile UANINTE_REG *)(UART2_1_REG_BASE_ADDR + 0x0E))).reg

/// ----- SPIA ----

/// SPIA Ch.0 Mode Register
#define SPI0MOD                 (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).reg

/// SPIA Ch.0 Control Register
#define SPI0CTL                 (*((volatile SPINCTL_REG *)(SPIA_0_REG_BASE_ADDR + 0x02))).reg

/// SPIA Ch.0 Transmit Data Register
#define SPI0TXD                 (*((volatile SPINTXD_REG *)(SPIA_0_REG_BASE_ADDR + 0x04))).reg

/// SPIA Ch.0 Receive Data Register
#define SPI0RXD                 (*((volatile SPINRXD_REG *)(SPIA_0_REG_BASE_ADDR + 0x06))).reg

/// SPIA Ch.0 Interrupt Flag Register
#define SPI0INTF                (*((volatile SPININTF_REG *)(SPIA_0_REG_BASE_ADDR + 0x08))).reg

/// SPIA Ch.0 Interrupt Enable Register
#define SPI0INTE                (*((volatile SPININTE_REG *)(SPIA_0_REG_BASE_ADDR + 0x0A))).reg

/// SPIA Ch.1 Mode Register
#define SPI1MOD                 (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).reg

/// SPIA Ch.1 Control Register
#define SPI1CTL                 (*((volatile SPINCTL_REG *)(SPIA_1_REG_BASE_ADDR + 0x02))).reg

/// SPIA Ch.1 Transmit Data Register
#define SPI1TXD                 (*((volatile SPINTXD_REG *)(SPIA_1_REG_BASE_ADDR + 0x04))).reg

/// SPIA Ch.1 Receive Data Register
#define SPI1RXD                 (*((volatile SPINRXD_REG *)(SPIA_1_REG_BASE_ADDR + 0x06))).reg

/// SPIA Ch.1 Interrupt Flag Register
#define SPI1INTF                (*((volatile SPININTF_REG *)(SPIA_1_REG_BASE_ADDR + 0x08))).reg

/// SPIA Ch.1 Interrupt Enable Register
#define SPI1INTE                (*((volatile SPININTE_REG *)(SPIA_1_REG_BASE_ADDR + 0x0A))).reg

/// ----- I2C -----

/// I2C Ch.0 Clock Control Register
#define I2C0CLK                 (*((volatile I2CNCLK_REG *)(I2C_0_REG_BASE_ADDR + 0x00))).reg

/// I2C Ch.0 Mode Register
#define I2C0MOD                 (*((volatile I2CNMOD_REG *)(I2C_0_REG_BASE_ADDR + 0x02))).reg

/// I2C Ch.0 Baud-Rate Register
#define I2C0BR                  (*((volatile I2CNBR_REG *)(I2C_0_REG_BASE_ADDR + 0x04))).reg

/// I2C Ch.0 Own Address Register
#define I2C0OADR                (*((volatile I2CNOADR_REG *)(I2C_0_REG_BASE_ADDR + 0x08))).reg

/// I2C Ch.0 Control Register
#define I2C0CTL                 (*((volatile I2CNCTL_REG *)(I2C_0_REG_BASE_ADDR + 0x0A))).reg

/// I2C Ch.0 Transmit Data Register
#define I2C0TXD                 (*((volatile I2CNTXD_REG *)(I2C_0_REG_BASE_ADDR + 0x0C))).reg

/// I2C Ch.0 Receive Data Register
#define I2C0RXD                 (*((volatile I2CNRXD_REG *)(I2C_0_REG_BASE_ADDR + 0x0E))).reg

/// I2C Ch.0 Status and Interrupt Flag Register
#define I2C0INTF                (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).reg

/// I2C Ch.0 Interrupt Enable Register
#define I2C0INTE                (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).reg

/// ----- T16B ------

/// T16B Ch.0 Clock Control Register
#define T16B0CLK                (*((volatile T16BNCLK_REG *)(T16B_0_REG_BASE_ADDR + 0x00))).reg

/// T16B Ch.0 Counter Control Register.
#define T16B0CTL                (*((volatile T16BNCTL_REG *)(T16B_0_REG_BASE_ADDR + 0x02))).reg

/// T16B Ch.0 Max Counter Data Register
#define T16B0MC                 (*((volatile T16BNMC_REG *)(T16B_0_REG_BASE_ADDR + 0x04))).reg

/// T16B Ch.0 Timer Counter Data Register.
#define T16B0TC                 (*((volatile T16BNTC_REG *)(T16B_0_REG_BASE_ADDR + 0x06))).reg

/// T16B Ch.0 Counter Status Register
#define T16B0CS                 (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).reg

/// T16B Ch.0 Interrupt Flag Register.
#define T16B0INTF               (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).reg

/// T16B Ch.0 Interrupt Enable Register.
#define T16B0INTE               (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).reg

/// T16B Ch.0 Comparator/Capture 0 Control Register.
#define T16B0CCCTL0             (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).reg

/// T16B Ch.0 Compare/Capture 0 Data Register.
#define T16B0CCR0               (*((volatile T16BNCCRM_REG *)(T16B_0_REG_BASE_ADDR + 0x12))).reg

/// T16B Ch.0 Comparator/Capture 1 Control Registerr.
#define T16B0CCCTL1             (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).reg

/// T16B Ch.0 Compare/Capture 1 Data Register.
#define T16B0CCR1               (*((volatile T16BNCCRM_REG *)(T16B_0_REG_BASE_ADDR + 0x1A))).reg

/// T16B Ch.1 Clock Control Register
#define T16B1CLK                (*((volatile T16BNCLK_REG *)(T16B_1_REG_BASE_ADDR + 0x00))).reg

/// T16B Ch.1 Counter Control Register.
#define T16B1CTL                (*((volatile T16BNCTL_REG *)(T16B_1_REG_BASE_ADDR + 0x02))).reg

/// T16B Ch.1 Max Counter Data Register
#define T16B1MC                 (*((volatile T16BNMC_REG *)(T16B_1_REG_BASE_ADDR + 0x04))).reg

/// T16B Ch.1 Timer Counter Data Register.
#define T16B1TC                 (*((volatile T16BNTC_REG *)(T16B_1_REG_BASE_ADDR + 0x06))).reg

/// T16B Ch.1 Counter Status Register
#define T16B1CS                 (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).reg

/// T16B Ch.1 Interrupt Flag Register.
#define T16B1INTF               (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).reg

/// T16B Ch.1 Interrupt Enable Register.
#define T16B1INTE               (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).reg

/// T16B Ch.1 Comparator/Capture 0 Control Register.
#define T16B1CCCTL0             (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).reg

/// T16B Ch.1 Compare/Capture 0 Data Register.
#define T16B1CCR0               (*((volatile T16BNCCRM_REG *)(T16B_1_REG_BASE_ADDR + 0x12))).reg

/// T16B Ch.1 Comparator/Capture 1 Control Register.
#define T16B1CCCTL1             (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).reg

/// T16B Ch.1 Compare/Capture 1 Data Register.
#define T16B1CCR1               (*((volatile T16BNCCRM_REG *)(T16B_1_REG_BASE_ADDR + 0x1A))).reg

/// T16B Ch.2 Clock Control Register
#define T16B2CLK                (*((volatile T16BNCLK_REG *)(T16B_2_REG_BASE_ADDR + 0x00))).reg

/// T16B Ch.2 Counter Control Register.
#define T16B2CTL                (*((volatile T16BNCTL_REG *)(T16B_2_REG_BASE_ADDR + 0x02))).reg

/// T16B Ch.2 Max Counter Data Register
#define T16B2MC                 (*((volatile T16BNMC_REG *)(T16B_2_REG_BASE_ADDR + 0x04))).reg

/// T16B Ch.2 Timer Counter Data Register.
#define T16B2TC                 (*((volatile T16BNTC_REG *)(T16B_2_REG_BASE_ADDR + 0x06))).reg

/// T16B Ch.2 Counter Status Register
#define T16B2CS                 (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).reg

/// T16B Ch.2 Interrupt Flag Register.
#define T16B2INTF               (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).reg

/// T16B Ch.2 Interrupt Enable Register.
#define T16B2INTE               (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).reg

/// T16B Ch.2 Comparator/Capture 0 Control Register.
#define T16B2CCCTL0             (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).reg

/// T16B Ch.2 Compare/Capture 0 Data Register.
#define T16B2CCR0               (*((volatile T16BNCCRM_REG *)(T16B_2_REG_BASE_ADDR + 0x12))).reg

/// T16B Ch.2 Comparator/Capture 1 Control Register.
#define T16B2CCCTL1             (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).reg

/// T16B Ch.2 Compare/Capture 1 Data Register.
#define T16B2CCR1               (*((volatile T16BNCCRM_REG *)(T16B_2_REG_BASE_ADDR + 0x1A))).reg

/// ----- SNDA ------

/// SNDA Clock Control Register
#define SNDCLK                  (*((volatile SNDCLK_REG *)(SNDA_REG_BASE_ADDR + 0x00))).reg

/// SNDA Select Register
#define SNDSEL                  (*((volatile SNDSEL_REG *)(SNDA_REG_BASE_ADDR + 0x02))).reg

/// SNDA Control Register
#define SNDCTL                  (*((volatile SNDCTL_REG *)(SNDA_REG_BASE_ADDR + 0x04))).reg

/// SNDA Data Register
#define SNDDAT                  (*((volatile SNDDAT_REG *)(SNDA_REG_BASE_ADDR + 0x06))).reg

/// SNDA Interrupt Flag Register
#define SNDINTF                 (*((volatile SNDINTF_REG *)(SNDA_REG_BASE_ADDR + 0x08))).reg

/// SNDA Interrupt Enable Register
#define SNDINTE                 (*((volatile SNDINTE_REG *)(SNDA_REG_BASE_ADDR + 0x0A))).reg

/// ----- REMC2 ------

/// REMC2 Clock Control Register
#define REMCLK                  (*((volatile REMCLK_REG *)(REMC2_REG_BASE_ADDR + 0x00))).reg

/// REMC2 Data Bit Counter Control Register.
#define REMDBCTL                (*((volatile REMDBCTL_REG *)(REMC2_REG_BASE_ADDR + 0x02))).reg

/// REMC2 Data Bit Counter Register.
#define REMDBCNT                (*((volatile REMDBCNT_REG *)(REMC2_REG_BASE_ADDR + 0x04))).reg

/// REMC2 Data Bit Active Pulse Length Register.
#define REMAPLEN                (*((volatile REMAPLEN_REG *)(REMC2_REG_BASE_ADDR + 0x06))).reg

/// REMC2 Data Bit Length Register.
#define REMDBLEN                (*((volatile REMDBLEN_REG *)(REMC2_REG_BASE_ADDR + 0x08))).reg

/// REMC2 Status and Interrupt Flag Register.
#define REMINTF                 (*((volatile REMINTF_REG *)(REMC2_REG_BASE_ADDR + 0x0A))).reg

/// REMC2 Interrupt Enable Register.
#define REMINTE                 (*((volatile REMINTE_REG *)(REMC2_REG_BASE_ADDR + 0x0C))).reg

/// REMC2 Carrier Waveform Register.
#define REMCARR                 (*((volatile REMCARR_REG *)(REMC2_REG_BASE_ADDR + 0x10))).reg

/// REMC2 Carrier Modulation Control Register.
#define REMCCTL                 (*((volatile REMCCTL_REG *)(REMC2_REG_BASE_ADDR + 0x12))).reg

/// ----- LCD32B-----

/// LCD32B Clock Control Register
#define LCD32CLK                (*((volatile LCD32CLK_REG *)(LCD32B_REG_BASE_ADDR + 0x00))).reg

/// LCD32B Control Register
#define LCD32CTL                (*((volatile LCD32CTL_REG *)(LCD32B_REG_BASE_ADDR + 0x02))).reg

/// LCD32B Timing Control Register 1
#define LCD32TIM1               (*((volatile LCD32TIM1_REG *)(LCD32B_REG_BASE_ADDR + 0x04))).reg

/// LCD32B Timing Control Register 2
#define LCD32TIM2               (*((volatile LCD32TIM2_REG *)(LCD32B_REG_BASE_ADDR + 0x06))).reg

/// LCD32B Power Control Register
#define LCD32PWR                (*((volatile LCD32PWR_REG *)(LCD32B_REG_BASE_ADDR + 0x08))).reg

/// LCD32B Display Control Register
#define LCD32DSP                (*((volatile LCD32DSP_REG *)(LCD32B_REG_BASE_ADDR + 0x0A))).reg

/// LCD32B COM Pin Control Register 0
#define LCD32COMC0              (*((volatile LCD32COMC0_REG *)(LCD32B_REG_BASE_ADDR + 0x0C))).reg

/// LCD32B COM Pin Control Register 1
#define LCD32COMC1              (*((volatile LCD32COMC1_REG *)(LCD32B_REG_BASE_ADDR + 0x0E))).reg

/// LCD32B Interrupt Flag Register
#define LCD32INTF               (*((volatile LCD32INTF_REG *)(LCD32B_REG_BASE_ADDR + 0x10))).reg

/// LCD32B Interrupt Enable Register
#define LCD32INTE               (*((volatile LCD32INTE_REG *)(LCD32B_REG_BASE_ADDR + 0x12))).reg

/// ----- RFC ------

/// RFC Ch.0 Clock Control Register
#define RFC0CLK                 (*((volatile RFCNCLK_REG *)(RFC_0_REG_BASE_ADDR + 0x00))).reg

/// RFC Ch.0 Control Register
#define RFC0CTL                 (*((volatile RFCNCTL_REG *)(RFC_0_REG_BASE_ADDR + 0x02))).reg

/// RFC Ch.0 Oscillation Trigger Register
#define RFC0TRG                 (*((volatile RFCNTRG_REG *)(RFC_0_REG_BASE_ADDR + 0x04))).reg

/// RFC Ch.0 Measurement Counter Low Register
#define RFC0MCL                 (*((volatile RFCNMCL_REG *)(RFC_0_REG_BASE_ADDR + 0x06))).reg

/// RFC Ch.0 Measurement Counter High Register
#define RFC0MCH                 (*((volatile RFCNMCH_REG *)(RFC_0_REG_BASE_ADDR + 0x08))).reg

/// RFC Ch.0 Measurement Counter Register
#define RFC0MC                  (*((volatile RFCNMC_DWORD_REG *)(RFC_0_REG_BASE_ADDR + 0x06))).reg

/// RFC Ch.0 Time Base Counter Low Register
#define RFC0TCL                 (*((volatile RFCNTCL_REG *)(RFC_0_REG_BASE_ADDR + 0x0A))).reg

/// RFC Ch.0 Time Base Counter High Register
#define RFC0TCH                 (*((volatile RFCNTCH_REG *)(RFC_0_REG_BASE_ADDR + 0x0C))).reg

/// RFC Ch.0 Time Base Counter Register
#define RFC0TC                  (*((volatile RFCNTC_DWORD_REG *)(RFC_0_REG_BASE_ADDR + 0x0A))).reg

/// RFC Ch.0 Interrupt Flag Register
#define RFC0INTF                (*((volatile RFCNINTF_REG *)(RFC_0_REG_BASE_ADDR + 0x0E))).reg

/// RFC Ch.0 Interrupt Enable Register
#define RFC0INTE                (*((volatile RFCNINTE_REG *)(RFC_0_REG_BASE_ADDR + 0x10))).reg

/// RFC Ch.1 Clock Control Register
#define RFC1CLK                 (*((volatile RFCNCLK_REG *)(RFC_1_REG_BASE_ADDR + 0x00))).reg

/// RFC Ch.1 Control Register
#define RFC1CTL                 (*((volatile RFCNCTL_REG *)(RFC_1_REG_BASE_ADDR + 0x02))).reg

/// RFC Ch.1 Oscillation Trigger Register
#define RFC1TRG                 (*((volatile RFCNTRG_REG *)(RFC_1_REG_BASE_ADDR + 0x04))).reg

/// RFC Ch.1 Measurement Counter Low Register
#define RFC1MCL                 (*((volatile RFCNMCL_REG *)(RFC_1_REG_BASE_ADDR + 0x06))).reg

/// RFC Ch.1 Measurement Counter High Register
#define RFC1MCH                 (*((volatile RFCNMCH_REG *)(RFC_1_REG_BASE_ADDR + 0x08))).reg

/// RFC Ch.1 Measurement Counter Register
#define RFC1MC                  (*((volatile RFCNMC_DWORD_REG *)(RFC_1_REG_BASE_ADDR + 0x06))).reg

/// RFC Ch.1 Time Base Counter Low Register
#define RFC1TCL                 (*((volatile RFCNTCL_REG *)(RFC_1_REG_BASE_ADDR + 0x0A))).reg

/// RFC Ch.1 Time Base Counter High Register
#define RFC1TCH                 (*((volatile RFCNTCH_REG *)(RFC_1_REG_BASE_ADDR + 0x0C))).reg

/// RFC Ch.1 Time Base Counter Register
#define RFC1TC                  (*((volatile RFCNTC_DWORD_REG *)(RFC_1_REG_BASE_ADDR + 0x0A))).reg

/// RFC Ch.1 Interrupt Flag Register
#define RFC1INTF                (*((volatile RFCNINTF_REG *)(RFC_1_REG_BASE_ADDR + 0x0E))).reg

/// RFC Ch.1 Interrupt Enable Register
#define RFC1INTE                (*((volatile RFCNINTE_REG *)(RFC_1_REG_BASE_ADDR + 0x10))).reg

/// ----- ADC12A ------

/// ADC12A Ch.0 Control Register
#define ADC12_0CTL              (*((volatile ADC12_NCTL_REG *)(ADC12A_0_REG_BASE_ADDR + 0x00))).reg

/// ADC12A Ch.0 Trigger/Analog Input Select Register
#define ADC12_0TRG              (*((volatile ADC12_NTRG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x02))).reg

/// ADC12A Ch.0 Configuration Register
#define ADC12_0CFG              (*((volatile ADC12_NCFG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x04))).reg

/// ADC12A Ch.0 Interrupt Flag Register
#define ADC12_0INTF             (*((volatile ADC12_NINTF_REG *)(ADC12A_0_REG_BASE_ADDR + 0x06))).reg

/// ADC12A Ch.0 Interrupt Enable Register
#define ADC12_0INTE             (*((volatile ADC12_NINTE_REG *)(ADC12A_0_REG_BASE_ADDR + 0x08))).reg

/// These bits are the A/D conversion results of the analog input signal 0.
#define ADC12_0AD0D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0A))).reg

/// These bits are the A/D conversion results of the analog input signal 1.
#define ADC12_0AD1D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0C))).reg

/// These bits are the A/D conversion results of the analog input signal 2.
#define ADC12_0AD2D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0E))).reg

/// These bits are the A/D conversion results of the analog input signal 3.
#define ADC12_0AD3D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x10))).reg

/// These bits are the A/D conversion results of the analog input signal 4.
#define ADC12_0AD4D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x12))).reg

/// These bits are the A/D conversion results of the analog input signal 5.
#define ADC12_0AD5D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x14))).reg

/// These bits are the A/D conversion results of the analog input signal 6.
#define ADC12_0AD6D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x16))).reg

/// These bits are the A/D conversion results of the analog input signal 7.
#define ADC12_0AD7D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x18))).reg

/// ----- TSRVR ------

/// TSRVR Ch.0 Temperature Sensor Control Register
#define TSRVR0TCTL              (*((volatile TSRVRNTCTL_REG *)(TSRVR_0_REG_BASE_ADDR + 0x00))).reg

/// TSRVR Ch.0 Reference Voltage Generator Control Register
#define TSRVR0VCTL              (*((volatile TSRVRNVCTL_REG *)(TSRVR_0_REG_BASE_ADDR + 0x02))).reg

#ifdef __cplusplus
}
#endif

#endif // C17W3X_REG_H__
