/************************************************************************//**
 *
 * @file    misc_reg.h
 *
 * @brief   Definition of the Misc Registers(MISC) Register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Nov. 2018    1.10
 *              - Change source code.
 *
 ******************************************************************************/
#ifndef MISC_REG_H__
#define MISC_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <c17_mcu_select.h>

/// MISC System Protect Register.
typedef union MSCPROT_REG_TAG {
    unsigned short  reg;
    struct MSCPROT_REG_BIT_TAG {
        /**
         * These bits protect the control registers related to the system against writings.
         * .PROT[15:0]
         *  These bits protect the control registers related to the system against writings.
         *    0x0096 (R/W): Disable system protection
         *    Other than 0x0096 (R/W): Enable system protection
         */
        unsigned short      PROT        :16;
    } bit;
    unsigned char   byte_reg[2];
} MSCPROT_REG;

/// MISC IRAM Size Register.
typedef union MSCIRAMSZ_REG_TAG {
    unsigned short  reg;
    struct MSCIRAMSZ_REG_BIT_TAG {
#if defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
    defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
    defined(C17_MCUSEL_M40) || \
    defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
    defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
    defined(C17_MCUSEL_F63)
        /**
         * These bits set the internal RAM size that can be used.
         * .IRAMSZ[2:0]
         *  These bits set the internal RAM size that can be used.
         * +-------------+-------------------+
         * | IRAMSZ[1:0] | Internal RAM size |
         * +-------------+-------------------+
         * |     0x3     |     Reserved      |
         * +-------------+-------------------+
         * |     0x2     |        2KB        |
         * +-------------+-------------------+
         * |     0x1     |        1KB        |
         * +-------------+-------------------+
         * |     0x0     |       512B        |
         * +-------------+-------------------+
         */
#endif
#if defined(C17_MCUSEL_M01) || \
    defined(C17_MCUSEL_M10) || \
    defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
    defined(C17_MCUSEL_W14) || \
    defined(C17_MCUSEL_W15)
        /**
         * These bits set the internal RAM size that can be used.
         * .IRAMSZ[2:0]
         *  These bits set the internal RAM size that can be used.
         * +-------------+-------------------+
         * | IRAMSZ[2:0] | Internal RAM size |
         * +-------------+-------------------+
         * |   0x7-0x4   |     Reserved      |
         * +-------------+-------------------+
         * |     0x3     |        4KB        |
         * +-------------+-------------------+
         * |     0x2     |        2KB        |
         * +-------------+-------------------+
         * |     0x1     |        1KB        |
         * +-------------+-------------------+
         * |     0x0     |       512B        |
         * +-------------+-------------------+
         */
#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
    defined(C17_MCUSEL_W16) || \
    defined(C17_MCUSEL_W18)
        /**
         * These bits set the internal RAM size that can be used.
         * .IRAMSZ[2:0]
         *  These bits set the internal RAM size that can be used.
         * +-------------+-------------------+
         * | IRAMSZ[2:0] | Internal RAM size |
         * +-------------+-------------------+
         * |   0x7-0x5   |     Reserved      |
         * +-------------+-------------------+
         * |     0x4     |        8KB        |
         * +-------------+-------------------+
         * |     0x3     |        4KB        |
         * +-------------+-------------------+
         * |     0x2     |        2KB        |
         * +-------------+-------------------+
         * |     0x1     |        1KB        |
         * +-------------+-------------------+
         * |     0x0     |       512B        |
         * +-------------+-------------------+
         */
#endif
#if defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35)
        /**
         * These bits set the internal RAM size that can be used.
         * .IRAMSZ[2:0]
         *  These bits set the internal RAM size that can be used.
         * +-------------+-------------------+
         * | IRAMSZ[2:0] | Internal RAM size |
         * +-------------+-------------------+
         * |   0x7-0x6   |     Reserved      |
         * +-------------+-------------------+
         * |     0x5     |       12KB        |
         * +-------------+-------------------+
         * |     0x4     |        8KB        |
         * +-------------+-------------------+
         * |     0x3     |        4KB        |
         * +-------------+-------------------+
         * |     0x2     |        2KB        |
         * +-------------+-------------------+
         * |     0x1     |        1KB        |
         * +-------------+-------------------+
         * |     0x0     |       512B        |
         * +-------------+-------------------+
         */
#endif
#if defined(C17_MCUSEL_589) || \
    defined(C17_MCUSEL_W36)
        /**
         * These bits set the internal RAM size that can be used.
         * .IRAMSZ[2:0]
         *  These bits set the internal RAM size that can be used.
         * +-------------+-------------------+
         * | IRAMSZ[2:0] | Internal RAM size |
         * +-------------+-------------------+
         * |     0x7     |     Reserved      |
         * +-------------+-------------------+
         * |     0x6     |       16KB        |
         * +-------------+-------------------+
         * |     0x5     |       12KB        |
         * +-------------+-------------------+
         * |     0x4     |        8KB        |
         * +-------------+-------------------+
         * |     0x3     |        4KB        |
         * +-------------+-------------------+
         * |     0x2     |        2KB        |
         * +-------------+-------------------+
         * |     0x1     |        1KB        |
         * +-------------+-------------------+
         * |     0x0     |       512B        |
         * +-------------+-------------------+
         */
#endif
        unsigned short      IRAMSZ      : 3;
        unsigned short      reserved_1  :13;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} MSCIRAMSZ_REG;

/// MISC Vector Table Address Low Register.
typedef union MSCTTBRL_REG_TAG {
    unsigned short  reg;
    struct MSCTTBRL_REG_BIT_TAG {
         /**
         * These bits set the vector table base address (16 low-order bits).
         * .TTBR[15:0]
         *  These bits set the vector table base address (16 low-order bits).
         */
        unsigned short      TTBR        : 16;
    } bit;
    unsigned char   byte_reg[2];
} MSCTTBRL_REG;

/// MISC Vector Table Address High Register.
typedef union MSCTTBRH_REG_TAG {
    unsigned short  reg;
    struct MSCTTBRH_REG_BIT_TAG {
        /**
         * These bits set the vector table base address (eight high-order bits).
         * .TTBR[23:16]
         *  These bits set the vector table base address (eight high-order bits).
         */
        unsigned short      TTBR        : 8;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} MSCTTBRH_REG;

/// MISC Vector Table Address Register.
typedef union MSCTTBR_DWORD_REG_TAG {
    unsigned long   reg;
} MSCTTBR_DWORD_REG;

/// MISC PSR Register.
typedef union MSCPSR_REG_TAG {
    unsigned short  reg;
    struct MSCPSR_REG_BIT_TAG {
        /**
         * The value (0 or 1) of the PSR N (negative) flag can be read out with this bit.
         * .PSRN
         *  The value (0 or 1) of the PSR N (negative) flag can be read out with this bit.
         */
        unsigned short      PSRN        : 1;
        /**
         * The value (0 or 1) of the PSR Z (zero) flag can be read out with this bit.
         * .PSRZ
         *  The value (0 or 1) of the PSR Z (zero) flag can be read out with this bit.
         */
        unsigned short      PSRZ        : 1;
        /**
         * The value (0 or 1) of the PSR V (overflow) flag can be read out with this bit.
         * .PSRV
         *  The value (0 or 1) of the PSR V (overflow) flag can be read out with this bit.
         */
        unsigned short      PSRV        : 1;
        /**
         * The value (0 or 1) of the PSR C (carry) flag can be read out with this bit.
         * .PSRC
         *  The value (0 or 1) of the PSR C (carry) flag can be read out with this bit.
         */
        unsigned short      PSRC        : 1;
        /**
         * The value (0 or 1) of the PSR IE (interrupt enable) bit can be read out with this bit.
         * .PSRIE
         *  The value (0 or 1) of the PSR IE (interrupt enable) bit can be read out with this bit.
         */
        unsigned short      PSRIE       : 1;
        /**
         * The value (0 to 7) of the PSR IL[2:0] (interrupt level) bits can be read out with these bits.
         * .PSRIL[2:0]
         *  The value (0 to 7) of the PSR IL[2:0] (interrupt level) bits can be read out with these bits.
         */
        unsigned short      PSRIL       : 3;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} MSCPSR_REG;

#ifdef __cplusplus
}
#endif

#endif // MISC_REG_H__
